<?php

$LANG = array(
    'organization' => 'Yritys',
    'name' => 'Nimi',
    'website' => 'Kotisivu',
    'work_phone' => 'Puhelin',
    'address' => 'Osoite',
    'address1' => 'Katu',
    'address2' => 'Asunto',
    'city' => 'Kaupunki',
    'state' => 'Lääni',
    'postal_code' => 'Postinumero',
    'country_id' => 'Maa',
    'contacts' => 'Yhteystiedot',
    'first_name' => 'Etunimi',
    'last_name' => 'Sukunimi',
    'phone' => 'Puhelin',
    'email' => 'Sähköposti',
    'additional_info' => 'Lisätiedot',
    'payment_terms' => 'Maksuehdot',
    'currency_id' => 'Valuutta',
    'size_id' => 'Yrityksen koko',
    'industry_id' => 'Toimiala',
    'private_notes' => 'Yksityiset muistiinpanot',
    'invoice' => 'Lasku',
    'client' => 'Asiakas',
    'invoice_date' => 'Laskun päivämäärä',
    'due_date' => 'Eräpäivä',
    'invoice_number' => 'Laskun numero',
    'invoice_number_short' => 'Laskun nro',
    'po_number' => 'Tilaus numero',
    'po_number_short' => 'Tilaus #',
    'frequency_id' => 'Kuinka usein',
    'discount' => 'Alennus',
    'taxes' => 'Verot',
    'tax' => 'Vero',
    'item' => 'Tuote',
    'description' => 'Kuvaus',
    'unit_cost' => 'Kappalehinta',
    'quantity' => 'Määrä',
    'line_total' => 'Rivin summa',
    'subtotal' => 'Välisumma',
    'paid_to_date' => 'Maksettu tähän mennessä',
    'balance_due' => 'Avoin lasku',
    'invoice_design_id' => 'Muotoilu',
    'terms' => 'Ehdot',
    'your_invoice' => 'Laskunne',
    'remove_contact' => 'Poista yhteystieto',
    'add_contact' => 'Lisää yhteystieto',
    'create_new_client' => 'Lisää uusi asiakas',
    'edit_client_details' => 'Muokkaa asiakkaan tietoja',
    'enable' => 'Ota käyttöön',
    'learn_more' => 'Lue lisää',
    'manage_rates' => 'Hallitse hintoja',
    'note_to_client' => 'Huomautus asiakkaalle',
    'invoice_terms' => 'Laskun ehdot',
    'save_as_default_terms' => 'Tallenna oletusehdot',
    'download_pdf' => 'Lataa PDF',
    'pay_now' => 'Maksa nyt',
    'save_invoice' => 'Tallenna lasku',
    'clone_invoice' => 'Kloonaa laskulle',
    'archive_invoice' => 'Arkistoi lasku',
    'delete_invoice' => 'Poista lasku',
    'email_invoice' => 'Lähetä lasku sähköpostitse',
    'enter_payment' => 'Kirjaa maksu',
    'tax_rates' => 'Verokannat',
    'rate' => 'Kanta',
    'settings' => 'Asetukset',
    'enable_invoice_tax' => 'Ota käyttöön määrittämällä <b>laskun verokanta</b>',
    'enable_line_item_tax' => 'Ota käyttöön <b>verot tuoteriveille</b>',
    'dashboard' => 'Hallintapaneeli',
    'dashboard_totals_in_all_currencies_help' => 'Huom: lisää  :link named ":name"  show  totals using  single base currency.',
    'clients' => 'Asiakkaat',
    'invoices' => 'Laskut',
    'payments' => 'Maksut',
    'credits' => 'Hyvitykset',
    'history' => 'Historia',
    'search' => 'Etsi',
    'sign_up' => 'Rekisteröidy',
    'guest' => 'Vieras',
    'company_details' => 'Yrityksen tiedot',
    'online_payments' => 'Online maksut',
    'notifications' => 'Sähköposti-ilmoitukset',
    'import_export' => 'Tuonti | Vienti',
    'done' => 'Valmis',
    'save' => 'Tallenna',
    'create' => 'Luo',
    'upload' => 'Lataa palvelimelle',
    'import' => 'Tuo',
    'download' => 'Lataa',
    'cancel' => 'Peruuta',
    'close' => 'Sulje',
    'provide_email' => 'Anna käypä sähköpostiosoite',
    'powered_by' => 'Moottorina',
    'no_items' => 'Ei tuotteita',
    'recurring_invoices' => 'Toistuvat laskut',
    'recurring_help' => '<p>automaattisesti lähetä asiakkaille sama lasku viikottain, kahdesti kuussa, kuukaisittain, neljännesvuosittain tai vuosittain. </p>
        <p>käytä :MONTH, :QUARTER tai :YEAR  dynaamisia päiväyksiä. Perus matematiikka toimii hyvin,  esimerkki :MONTH-1.</p>
        <p>Examples  dynamic lasku variables:</p>
        <ul>
          <li>"Gym membership for  kuukausi of :MONTH" >> "Gym membership for  kuukausi  July"</li>
          <li>":YEAR+1 vuosittain tilaus" >> "2015 Yearly tilaus"</li>
          <li>"Retainer maksu for :QUARTER+1" >> "Retainer maksu  Q2"</li>
        </ul>',
    'recurring_quotes' => 'Toistuvat tarjoukset',
    'in_total_revenue' => 'kokonaistuloja',
    'billed_client' => 'Laskutettu asiakas',
    'billed_clients' => 'Laskutetut asiakaat',
    'active_client' => 'Aktiivinen asiakas',
    'active_clients' => 'Aktiiviset asiakkaat',
    'invoices_past_due' => 'Eräntyneet laskut',
    'upcoming_invoices' => 'Erääntyvät laskut',
    'average_invoice' => 'Laskujen keskiarvo',
    'archive' => 'Arkisto',
    'delete' => 'Poista',
    'archive_client' => 'Arkistoi asiakas',
    'delete_client' => 'Poista asiakas',
    'archive_payment' => 'Arkistoi maksu',
    'delete_payment' => 'Poista maksu',
    'archive_credit' => 'Arkistoi hyvityslasku',
    'delete_credit' => 'Poista hyvityslasku',
    'show_archived_deleted' => 'Näytä arkistoidut / poistetut',
    'filter' => 'Suodata',
    'new_client' => 'Uusi asiakas',
    'new_invoice' => 'Uusi lasku',
    'new_payment' => 'Uusi maksutapahtuma',
    'new_credit' => 'Anna hyvitys',
    'contact' => 'Yhteyshenkilö',
    'date_created' => 'Luotu',
    'last_login' => 'Viimeinen kirjautuminen',
    'balance' => 'Saldo',
    'action' => 'Toiminto',
    'status' => 'Tila',
    'invoice_total' => 'Maksettava',
    'frequency' => 'Kuinka usein',
    'range' => 'Alue',
    'start_date' => 'Alkamispäivämäärä',
    'end_date' => 'Loppupäivämäärä',
    'transaction_reference' => 'Tapahtuman viite',
    'method' => 'Tapa',
    'payment_amount' => 'Maksun määrä',
    'payment_date' => 'Maksun päivämäärä',
    'credit_amount' => 'Hyvityksen määrä',
    'credit_balance' => 'Hyvityksen saldo',
    'credit_date' => 'Hyvityksen päivämäärä',
    'empty_table' => 'Ei näytettävä data',
    'select' => 'Valitse',
    'edit_client' => 'Muokkaa asiakas',
    'edit_invoice' => 'Muokkaa laskua',
    'create_invoice' => 'Luo lasku',
    'enter_credit' => 'Kirjaa hyvitystä',
    'last_logged_in' => 'Viimeksi kirjoittautunut',
    'details' => 'Tiedot',
    'standing' => 'Tilanne',
    'credit' => 'Luotto',
    'activity' => 'Toiminta',
    'date' => 'Päivämäärä',
    'message' => 'Viesti',
    'adjustment' => 'Säätö',
    'are_you_sure' => 'Oletko varma?',
    'payment_type_id' => 'Maksun tyyppi',
    'amount' => 'Määrä',
    'work_email' => 'Sähköposti',
    'language_id' => 'Kieli',
    'timezone_id' => 'Aikavyöhyke',
    'date_format_id' => 'Päivämäärän muoto',
    'datetime_format_id' => 'Päivä- / Aikamuoto',
    'users' => 'Käyttäjät',
    'localization' => 'Lokalisointi',
    'remove_logo' => 'Poista Logo',
    'logo_help' => 'Tuetut: JPEG, GIF ja PNG',
    'payment_gateway' => 'Maksuterminaali',
    'gateway_id' => 'Terminaali',
    'email_notifications' => 'Sähköposti ilmoitukset',
    'email_sent' => 'Lähetä minulle sähköposti, kun lasku on <b>lähetetty</b>',
    'email_viewed' => 'Lähetä minulle sähköposti, kun lasku on <b>nähty</b>',
    'email_paid' => 'Lähetä minulle sähköposti, kun lasku on <b>maksettu</b>',
    'site_updates' => 'Sivun päivitys',
    'custom_messages' => 'Mukautetut viestit',
    'default_email_footer' => 'Aseta vakiomuotoinen <b>sähköpostiallekirjoitus</b>',
    'select_file' => 'ystävällisesti valitsee tiedosto',
    'first_row_headers' => 'Käytä ensimmäinen rivi ylätunnisteena',
    'column' => 'Sarake',
    'sample' => 'Otos',
    'import_to' => 'Tuo tähän',
    'client_will_create' => 'Asiakas luodaan',
    'clients_will_create' => 'Asiakkaita luodaan',
    'email_settings' => 'Sähköpostin asetukset',
    'client_view_styling' => 'Muokkaa asiakkaan näky',
    'pdf_email_attachment' => 'Liitä PDF-lasku',
    'custom_css' => 'Mukautettu CSS',
    'import_clients' => 'Tuo asiakkaan tiedot',
    'csv_file' => 'CSV tiedosto',
    'export_clients' => 'Vie asiakkaan tiedot ',
    'created_client' => 'Luotin onnistuneesti asiakas',
    'created_clients' => ':count asiakas(ta) luotu onnistuneesti',
    'updated_settings' => 'Asetukset ovat päivittyneet onnistuneesti',
    'removed_logo' => 'Logo on poistettu onnistuneesti ',
    'sent_message' => 'Viesti on onnistuneesti lähetetty',
    'invoice_error' => 'Ystävällisesti varmistakaa että asiakasta on valittu ja korjaatkaa kaikki virheet',
    'limit_clients' => 'Pahoittelut, tämä ylittää :count asiakkaan rajan',
    'payment_error' => 'Maksukäsittelyssä ilmeni ongelma. Yrittäkää myöhemmin uudelleen.',
    'registration_required' => 'Rekisteröidy lähettääksesi laskun',
    'confirmation_required' => 'Ole hyvä ja vahvista sähköpostiosoitteesi, :link paina tästä uudelleenlähettääksesi vahvistussähköpostin. ',
    'updated_client' => 'Asiakas on päivitetty onnistuneesti',
    'archived_client' => 'Asiakas on arkistoitu onnistuneesti',
    'archived_clients' => ':count asiakas(ta) arkistoitu onnistuneesti',
    'deleted_client' => 'Asiakas on poistettu onnistuneesti',
    'deleted_clients' => ':count asiakas(ta) poistettu onnistuneesti',
    'updated_invoice' => 'Lasku päivitettiin onnistuneesti',
    'created_invoice' => 'Lasku luotiin onnistuneesti ',
    'cloned_invoice' => 'Lasku kopioitiin onnistuneesti',
    'emailed_invoice' => 'Lasku lähetettiin onnistuneesti',
    'and_created_client' => 'ja luotu asiakas',
    'archived_invoice' => 'Lasku arkistoitiin onnistuneesti',
    'archived_invoices' => ':count asiakas(ta) arkistoitu onnistuneesti',
    'deleted_invoice' => 'Lasku poistettiin onnistuneesti',
    'deleted_invoices' => ':count laskua poistettiin onnistuneesti',
    'created_payment' => 'Maksu on luotu onnistuneesti',
    'created_payments' => ':count maksu(a) luotu onnistuneesti',
    'archived_payment' => 'Maksu on arkistoitu onnistuneesti',
    'archived_payments' => ':count maksu(a) arkistoitu onnistuneesti',
    'deleted_payment' => 'Maksu on poistettu onnistuneesti',
    'deleted_payments' => ':count maksu(a) poistettu onnistuneesti',
    'applied_payment' => 'Maksu on sovitettu onnistuneesti. ',
    'created_credit' => 'Hyvitys on luotu onnistuneesti',
    'archived_credit' => 'Hyvitys on arkistoitu onnistuneesti',
    'archived_credits' => ':count hyvitys(tä) arkistoitu onnistuneesti',
    'deleted_credit' => 'Hyvitys on poistettu onnistuneesti',
    'deleted_credits' => ':count hyvitys(tä) poistettu onnistuneesti',
    'imported_file' => 'Tiedosto on tuotu onnistuneesti',
    'updated_vendor' => 'Kauppias on päivitetty onnistuneesti',
    'created_vendor' => 'Kauppias luotin onnistuneesti',
    'archived_vendor' => 'Kauppias on arkistoitu onnistuneesti',
    'archived_vendors' => ':count kauppias(ta) arkistoitu onnistuneesti',
    'deleted_vendor' => 'Kauppias on poistettu onnistuneesti',
    'deleted_vendors' => ':count kauppias(ta) poistettu onnistuneesti',
    'confirmation_subject' => 'Lasku Ninja -tilin vahvistus',
    'confirmation_header' => 'Tilin varmistus',
    'confirmation_message' => 'Ystävällisesti seuraa alla oleva linkkiä varmistaaksesi tilisi. ',
    'invoice_subject' => 'Uusi :tili lasku :invoice',
    'invoice_message' => 'Nähdäksesi laskun summalle :amount, paina alla olevaa linkkiä.',
    'payment_subject' => 'Maksu vastaanotettu',
    'payment_message' => 'Kiitos :amount maksustasi.',
    'email_salutation' => 'Hyvä :name,',
    'email_signature' => 'Ystävällisesti,',
    'email_from' => 'Invoive Ninja -tiimi',
    'invoice_link_message' => 'Nähdäksesi laskun paina alla olevaa linkkiä: ',
    'notification_invoice_paid_subject' => ':client maksoi laskun :invoice',
    'notification_invoice_sent_subject' => 'Lasku :invoice lähetetty asiakkaalle :client',
    'notification_invoice_viewed_subject' => ':client luki laskun :invoice',
    'notification_invoice_paid' => 'Asiakas :client maksoi :amount laskusta :invoice.',
    'notification_invoice_sent' => 'Asiakkaalle :client lähetettiin lasku :invoice summalla :amount.',
    'notification_invoice_viewed' => 'Asiakas :client avasi laskun :invoice summalla :amount.',
    'reset_password' => 'Voit palauttaa tilisi salasana klikkaamalla nappia',
    'secure_payment' => 'Turvallinen maksu',
    'card_number' => 'Kortin numero',
    'expiration_month' => 'Voimassaolo kuukausi',
    'expiration_year' => 'Voimassaolo vuosi',
    'cvv' => 'CVV',
    'logout' => 'Kirjaudu ulos',
    'sign_up_to_save' => 'Rekisteröidy tallentaaksesi työsi',
    'agree_to_terms' => 'Hyväksyn Lasku Ninjan :terms',
    'terms_of_service' => 'Käyttöehdot',
    'email_taken' => 'Sähköpostiosoite on jo rekisteröity',
    'working' => 'Mietti',
    'success' => 'Onnistui',
    'success_message' => 'Olet rekisteröity onnistuneesti! Seuraa sähköpostin tullutta linkkiä varmistaaksesi sähköpostiosoitettasi. ',
    'erase_data' => 'Tiliäsi ei ole rekisteröity, tämä poistaa tietosi pysyvästi.',
    'password' => 'Salasana',
    'pro_plan_product' => 'Pro tili',
    'pro_plan_success' => 'kiitos  choosing Lasku Ninja\'s Pro plan!<p/>&nbsp;<br/>
                          <b>Next Steps</b><p/>A payable lasku on lähettää    sähköposti
                          osoite associated  tilisi. To unlock kaikki of  awesome
                          Pro ominaisuudet,  seuraa  ohjeet on  lasku  pay
                          for  year  Pro-level invoicing.<p/>
                          Can\'t find  lasku? Need further assistance? We\'re happy  help
                          -- sähköposti us at kontakti@invoiceninja.com',
    'unsaved_changes' => 'Sinulla on tallentamattomat muutoksia ',
    'custom_fields' => 'Mukautetut kentät',
    'company_fields' => 'Yritys kentät',
    'client_fields' => 'Asiakas kentät',
    'field_label' => 'Kentän nimike',
    'field_value' => 'Kentän arvo',
    'edit' => 'Muokkaa',
    'set_name' => 'Anna yrityksesi nimi',
    'view_as_recipient' => 'Näe vastaanottajan näkökulmasta',
    'product_library' => 'Tuoteluettelo',
    'product' => 'Tuote',
    'products' => 'Tuotteet',
    'fill_products' => 'Lisää automaattisesti tuotteita',
    'fill_products_help' => 'Tuotteen valinta <b>täyttää kuvauksen ja hinnan</b> automaattisesti',
    'update_products' => 'Päivitä automaattisesti tuotteet',
    'update_products_help' => 'Laskun päivittäminen <b>päivittää tuotetietokannan</b> automaattisesti',
    'create_product' => 'Lisää tuote',
    'edit_product' => 'Muokkaa tuote',
    'archive_product' => 'Arkistoi tuote',
    'updated_product' => 'Tuote on päivitetty onnistuneesti',
    'created_product' => 'Tuote on luotu onnistuneesti',
    'archived_product' => 'Tuote on arkistoitu onnistuneesti',
    'pro_plan_custom_fields' => ':link ottaaksesi käyttöön räätälöidyt kentät liittymällä Pro-tasoon',
    'advanced_settings' => 'Lisääasetuksia',
    'pro_plan_advanced_settings' => ':link ottaaksesi käyttöön Pro-tason lisäasetukset',
    'invoice_design' => 'Laskun muotoilu',
    'specify_colors' => 'Tarkenna värit',
    'specify_colors_label' => 'Valitsee laskussa käytettävät värit',
    'chart_builder' => 'Kaavion rakentaminen',
    'ninja_email_footer' => 'Luotu käyttäen :site | Luo. Lähetä. Vastaanota maksut.',
    'go_pro' => 'Ala PRO:ksi',
    'quote' => 'Tarjous',
    'quotes' => 'Tarjoukset',
    'quote_number' => 'Tarjous numero',
    'quote_number_short' => 'Tarjous #',
    'quote_date' => 'Tarjouksen päivämäärä',
    'quote_total' => 'Tarjouksen loppusumma',
    'your_quote' => 'Tarjouksenne',
    'total' => 'Loppusumma',
    'clone' => 'Kopioi',
    'new_quote' => 'Uusi tarjous',
    'create_quote' => 'Luo tarjous',
    'edit_quote' => 'Muokkaa tarjousta',
    'archive_quote' => 'Arkistoi tarjous',
    'delete_quote' => 'Poista tarjous',
    'save_quote' => 'Tallenna tarjous',
    'email_quote' => 'Lähetä tarjous sähköpostitse',
    'clone_quote' => 'Kopioi tarjous',
    'convert_to_invoice' => 'Muuta laskuksi',
    'view_invoice' => 'Katso lasku',
    'view_client' => 'Katso asiakasta',
    'view_quote' => 'Tarkastele tarjousta',
    'updated_quote' => 'Tarjous on päivitetty onnistuneesti',
    'created_quote' => 'Tarjous on luotu onnistuneesti',
    'cloned_quote' => 'Tarjous on kopioitu onnistuneesti',
    'emailed_quote' => 'Tarjous on lähetetty onnistuneesti',
    'archived_quote' => 'Tarjous on arkistoitu onnistuneesti',
    'archived_quotes' => ':count tarjous(ta) arkistoitu onnistuneesti',
    'deleted_quote' => 'Tarjous on poistettu onnistuneesti',
    'deleted_quotes' => ':count tarjous(ta) poistettu onnistuneesti',
    'converted_to_invoice' => 'Tarjous muutettu laskuksi onnistuneesti',
    'quote_subject' => 'Uusi tarjous :quote yritykseltä :tili',
    'quote_message' => 'Nähdäksesi tarjouksen summalla :amount, paina alla olevaa linkkiä.',
    'quote_link_message' => 'Paina linkkiä alla nähdäksesi asiakkaasi tarjouksen:',
    'notification_quote_sent_subject' => 'Tarjous :invoice on lähetetty asiakkaalle :client',
    'notification_quote_viewed_subject' => ':client luki tarjouksen :invoice ',
    'notification_quote_sent' => 'Asiakkaalle :client lähetettiin tarjous :invoice summalla :amount.',
    'notification_quote_viewed' => 'Asiakas :client avasi tarjouksen :invoice summalla :amount.',
    'session_expired' => 'Istuntosi on vanhentunut',
    'invoice_fields' => 'Laskun kentät',
    'invoice_options' => 'Laskun valinnat',
    'hide_paid_to_date' => 'Piilota "Maksettu tähän asti"',
    'hide_paid_to_date_help' => 'Näytä "Maksettava päivämäärään mennessä" kenttä laskuillasi vain maksetuilla laskuilla.',
    'charge_taxes' => 'Veloita veroa',
    'user_management' => 'Käyttäjänhallinta',
    'add_user' => 'Lisää käyttäjä',
    'send_invite' => 'Lähetä kutsu',
    'sent_invite' => 'Kutsu on onnistuneesti lähetetty',
    'updated_user' => 'Käyttäjä on päivitetty onnistuneesti',
    'invitation_message' => 'Olet saanut kutsun käyttäjältä :invitor.',
    'register_to_add_user' => 'Rekisteröidy lisäätäksesi Käyttäjä',
    'user_state' => 'Tila',
    'edit_user' => 'Muokkaa käyttäjä',
    'delete_user' => 'Poista Käyttäjä',
    'active' => 'Aktiivinen',
    'pending' => 'Odottaa vastausta',
    'deleted_user' => 'Käyttäjä on poistettu onnistuneesti',
    'confirm_email_invoice' => 'Haluatko varmasti lähettää tämän laskun?',
    'confirm_email_quote' => 'Haluatko varmasti lähettää sähköpostitse tämän tarjouksen',
    'confirm_recurring_email_invoice' => 'Oletko varmaa että haluat lähettää tämän laskun?',
    'confirm_recurring_email_invoice_not_sent' => 'Oletko varma, että haluat aloittaa toistuvuuden?',
    'cancel_account' => 'Poista tili',
    'cancel_account_message' => 'Varoitus: Tämä poistaa tilisi pysyvästi. Tietoja ei pysty palauttamaan.',
    'go_back' => 'Palaa takaisin',
    'data_visualizations' => 'Datan visualisaatiot',
    'sample_data' => 'Näytetään esimerkkitietoja',
    'hide' => 'Piilota',
    'new_version_available' => 'Uusi versio ohjelmistosta :releases_link saatavilla. Tämänhetkinen versio on v:user_version, uusin versio on v:latest_version',
    'invoice_settings' => 'Laskun asetukset',
    'invoice_number_prefix' => 'Laskunumeron etuliite',
    'invoice_number_counter' => 'Laskun järjestysnumero',
    'quote_number_prefix' => 'Tarjousnumeron etuliite',
    'quote_number_counter' => 'Tarjouksen järjestysnumero',
    'share_invoice_counter' => 'Jaa järjestysnumero laskun kanssa',
    'invoice_issued_to' => 'Laskutettu asiakas',
    'invalid_counter' => 'Estääksesi mahdolliset konfliktit, aseta laskulle tai tarjoukselle etuliite',
    'mark_sent' => 'Merkitse lähetetyksi',
    'gateway_help_1' => ':link rekisteröityäksesi palveluun Authorize.net.',
    'gateway_help_2' => ':link rekisteröityäksesi palveluun Authorize.net.',
    'gateway_help_17' => ':link saadaksesi PayPal API tilin.',
    'gateway_help_27' => ':link rekisteröityäksesi palveluun 2Checkout.com. Varmistaaksesi laskujen seurannan aseta uudelleenohjausosoitteeksi :complete_link kohdassa Tili > Sivustoasetukset 2Checkout portaalissa.',
    'gateway_help_60' => ':link luodaksesi WePay-tilin',
    'more_designs' => 'Lisää muotoiluja',
    'more_designs_title' => 'Lisää laskumuotoiluja',
    'more_designs_cloud_header' => 'Tilaa Pro saadaksesi lisää muotoiluja',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Osta',
    'bought_designs' => 'Laskumuotoilut lisätty onnistuneesti',
    'sent' => 'Lähetetty',
    'vat_number' => 'ALV-numero',
    'timesheets' => 'Työaikalistaukset',
    'payment_title' => 'Anna laskutusosoitteesi ja luottokorttitietosi',
    'payment_cvv' => '*Tämä on 3-4 -numeroinen koodi kortin takana',
    'payment_footer1' => '*Laskutusosoitteen täytyy täsmätä luottokortin osoitteen kanssa',
    'payment_footer2' => '*Paina "MAKSA NYT" -linkkiä vain kerran - maksutapahtuman käsittelyyn voi mennä jopa 1 minuutti.',
    'id_number' => 'Asiakasnumero',
    'white_label_link' => 'White label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'White label -lisenssi otettu käyttöön onnistuneesti',
    'white_labeled' => 'White label käytössä',
    'restore' => 'Palauta',
    'restore_invoice' => 'Palauta lasku',
    'restore_quote' => 'Palauta tarjous',
    'restore_client' => 'Palauta asiakas',
    'restore_credit' => 'Palauta hyvitys',
    'restore_payment' => 'Palauta maksu',
    'restored_invoice' => 'Lasku palautettu onnistuneesti',
    'restored_quote' => 'Tarjous palautettu onnistuneesti',
    'restored_client' => 'Asiakas palautettu onnistuneesti',
    'restored_payment' => 'Maksu palautettu onnistuneesti',
    'restored_credit' => 'Hyvitys palautettu onnistuneesti',
    'reason_for_canceling' => 'Auta meitä parantamaan sivustoamme kertomalla miksi olet lähdössä.',
    'discount_percent' => 'Prosenttia',
    'discount_amount' => 'Summa',
    'invoice_history' => 'Laskuhistoria',
    'quote_history' => 'Tarjoushistoria',
    'current_version' => 'Nykyinen versio',
    'select_version' => 'Valitse versio',
    'view_history' => 'Näytä historia',
    'edit_payment' => 'Muokkaa maksua',
    'updated_payment' => 'Maksu päivitetty onnistuneesti',
    'deleted' => 'Poistettu',
    'restore_user' => 'Palauta käyttäjä',
    'restored_user' => 'Käyttäjä palautettu onnistuneesti',
    'show_deleted_users' => 'Näytä poistetut käyttäjät',
    'email_templates' => 'Sähköpostipohjat',
    'invoice_email' => 'Laskusähköposti',
    'payment_email' => 'Maksusähköposti',
    'quote_email' => 'Tarjoussähköposti',
    'reset_all' => 'Nollaa kaikki',
    'approve' => 'Hyväksy',
    'token_billing_type_id' => 'Token laskutus',
    'token_billing_help' => 'Tallenna maksutiedot WePay, Stripe, Braintree tai GoCardless avulla.',
    'token_billing_1' => 'Pois käytöstä',
    'token_billing_2' => 'Opt-in - valinta näytetään mutta on vakiona valitsematta',
    'token_billing_3' => 'Opt-out - valinta näytetään ja on vakiona valittu',
    'token_billing_4' => 'Aina',
    'token_billing_checkbox' => 'Kaupan luottokorttitiedot',
    'view_in_gateway' => 'Näytä palvelussa :gateway',
    'use_card_on_file' => 'Käytä tallennettuja korttitietoja',
    'edit_payment_details' => 'Muokkaa maksun tietoja',
    'token_billing' => 'Tallenna korttitiedot',
    'token_billing_secure' => 'Tiedot on tallennettu turvallisesti palvelussa :link',
    'support' => 'Asiakaspalvelu',
    'contact_information' => 'Yhteystiedot',
    '256_encryption' => '256-bittinen salaus',
    'amount_due' => 'Maksettava',
    'billing_address' => 'Laskutusosoite',
    'billing_method' => 'Laskutustapa',
    'order_overview' => 'Tilaustiedot',
    'match_address' => '*Osoitteen on täsmättävä luottokorttitietojen kanssa',
    'click_once' => '*Paina "MAKSA NYT" -linkkiä vain kerran - maksutapahtuman käsittelyyn voi mennä jopa 1 minuutti.',
    'invoice_footer' => 'Laskun alatunniste',
    'save_as_default_footer' => 'Tallenna vakioalatunnisteeksi',
    'token_management' => 'Tokenin hallinta',
    'tokens' => 'Tokenit',
    'add_token' => 'Lisää Token',
    'show_deleted_tokens' => 'Näytä poistetut tokenit',
    'deleted_token' => 'Token poistettu onnistuneesti',
    'created_token' => 'Token luotu onnistuneesti',
    'updated_token' => 'Token päivitetty onnistuneesti',
    'edit_token' => 'Muokkaa tokenia',
    'delete_token' => 'Poista token',
    'token' => 'Token',
    'add_gateway' => 'Lisää maksunvälittäjä',
    'delete_gateway' => 'Poista maksunvälittäjä',
    'edit_gateway' => 'Muokkaa maksunvälittäjää',
    'updated_gateway' => 'Maksunvälittäjä päivitetty onnistuneesti',
    'created_gateway' => 'Maksunvälittäjä luotu onnistuneesti',
    'deleted_gateway' => 'Maksunvälittäjä poistettu onnistuneesti',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Luottokortti',
    'change_password' => 'Muuta salasana',
    'current_password' => 'Nykyinen salasana',
    'new_password' => 'Uusi salasana',
    'confirm_password' => 'Vahvista salasana',
    'password_error_incorrect' => 'Nykyinen salasana on väärin',
    'password_error_invalid' => 'Uusi salasana ei kelpaa',
    'updated_password' => 'Salasana muutettu onnistuneesti',
    'api_tokens' => 'API-salasanat',
    'users_and_tokens' => 'Käyttäjät ja salasanat',
    'account_login' => 'Tiliin kirjautuminen',
    'recover_password' => 'Palauta salasana',
    'forgot_password' => 'Unohditko salasanasi?',
    'email_address' => 'Sähköpostiosoite',
    'lets_go' => 'Mennään',
    'password_recovery' => 'Salasanan palautus',
    'send_email' => 'Lähetä sähköposti',
    'set_password' => 'Aseta salasana',
    'converted' => 'Muunnettu',
    'email_approved' => 'Lähetä minulle sähköpostia kun tarjous on <b>hyväksytty</b>',
    'notification_quote_approved_subject' => ':client hyväksyi tarjouksen :invoice',
    'notification_quote_approved' => 'Asiakas :client avasi tarjouksen :invoice summalla :amount.',
    'resend_confirmation' => 'Lähetä vahvistussähköposti uudelleen',
    'confirmation_resent' => 'Vahvistussähköposti lähetetty',
    'gateway_help_42' => ':link rekisteröityäksesi palveluun BitPay.<br/>Huom: Käytä Legacy API Key -merkkijonoa, älä API tokenia.',
    'payment_type_credit_card' => 'Luottokortti',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Tietopankki',
    'partial' => 'Osittainen/Talletus',
    'partial_remaining' => ':partial summasta :balance',
    'more_fields' => 'Lisää kenttiä',
    'less_fields' => 'Vähemmän kenttiä',
    'client_name' => 'Asiakkaan nimi',
    'pdf_settings' => 'PDF-asetukset',
    'product_settings' => 'Tuoteasetukset',
    'auto_wrap' => 'Automaattinen rivinvaihto',
    'duplicate_post' => 'Varoitus: Edellinen sivu tallennettiin kahdesti. Jälkimmäinen tallennus jätettiin huomiotta.',
    'view_documentation' => 'Lue dokumentaatiota',
    'app_title' => 'Ilmainen vapaan lähdekoodin online-laskutus',
    'app_description' => 'Lasku Ninja on ilmainen, avoimen lähdekoodin ratkaisu asiakkaiden laskutukseen. Lasku Ninjalla voit helposti luoda ja lähettää kauniita laskuja mistä tahansa laitteesta, jolla on internet-yhteys. Asiakkaasi voivat tulostaa laskuja, ladata ne pdf-muodossa ja jopa maksaa ne verkossa järjestemmämme avulla.',
    'rows' => 'rivit',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Alidomain',
    'provide_name_or_email' => 'Ole hyvä ja anna nimi tai sähköposti',
    'charts_and_reports' => 'Kaaviot ja raportit',
    'chart' => 'Kaavio',
    'report' => 'Raportti',
    'group_by' => 'Niputa',
    'paid' => 'Maksettu',
    'enable_report' => 'Raportti',
    'enable_chart' => 'Kaavio',
    'totals' => 'Yhteensä',
    'run' => 'Aja',
    'export' => 'Vienti',
    'documentation' => 'Dokumentaatio',
    'zapier' => 'Zapier',
    'recurring' => 'Toistuvat',
    'last_invoice_sent' => 'Viimeisin lasku lähetettiin :päivämäärä',
    'processed_updates' => 'Päivitetty onnistuneesti',
    'tasks' => 'Tehtävät',
    'new_task' => 'Uusi tehtävä',
    'start_time' => 'Aloitusaika',
    'created_task' => 'Tehtävä luotu onnistuneesti',
    'updated_task' => 'Tehtävä päivitetty onnistuneesti',
    'edit_task' => 'Muokkaa tehtävä',
    'clone_task' => 'Kopioi tehtävä',
    'archive_task' => 'Arkistoi tehtävä',
    'restore_task' => 'Palauta tehtävä',
    'delete_task' => 'Poista tehtävä',
    'stop_task' => 'Poista tehtävä',
    'time' => 'Aika',
    'start' => 'Aloitus',
    'stop' => 'Lopetus',
    'now' => 'Nyt',
    'timer' => 'Ajastin',
    'manual' => 'Manuaalinen',
    'date_and_time' => 'Päivä & Aika',
    'second' => 'Sekunti',
    'seconds' => 'Sekuntia',
    'minute' => 'Minuutti',
    'minutes' => 'Minuuttia',
    'hour' => 'Tunti',
    'hours' => 'Tuntia',
    'task_details' => 'Tehtävän tiedot',
    'duration' => 'Kesto',
    'time_log' => 'Aikaloki',
    'end_time' => 'Lopetusaika',
    'end' => 'Loppu',
    'invoiced' => 'Laskutettu',
    'logged' => 'Kirjattu',
    'running' => 'Käynnissä',
    'task_error_multiple_clients' => 'Tehtävät eivät voi kuulua eri asiakkaille',
    'task_error_running' => 'Ole hyvä ja lopeta tehtävä ensin',
    'task_error_invoiced' => 'Tehtävät on jo laskutettu',
    'restored_task' => 'Tehtävä palautettu onnistuneesti',
    'archived_task' => 'Tehtävä arkistoitu onnistuneesti',
    'archived_tasks' => ':count tehtävää arkistoitu onnistuneesti',
    'deleted_task' => 'Tehtävä poistettu onnistuneesti',
    'deleted_tasks' => ':count tehtävää poistettu onnistuneesti',
    'create_task' => 'Luo tehtävä',
    'stopped_task' => 'Tehtävä lopetettu onnistuneesti',
    'invoice_task' => 'Laskuta tehtävä',
    'invoice_labels' => 'Laskun kentät',
    'prefix' => 'Etuliite',
    'counter' => 'Laskuri',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link rekisteröityäksesi palveluun Dwolla',
    'partial_value' => 'Täytyy olla suurempi kuin nolla ja vähemmän kuin kaikki yhteensä',
    'more_actions' => 'Lisää toimintoja',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Päivitä nyt!',
    'pro_plan_feature1' => 'Luo rajattomasti asiakkaita',
    'pro_plan_feature2' => 'Käytä 10 kaunista laskupohjaa',
    'pro_plan_feature3' => 'Mukautetut osoitteet - "yrityksesi.invoiceninja.com"',
    'pro_plan_feature4' => 'Poista "Tehty Lasku Ninjalla"',
    'pro_plan_feature5' => 'Multi-käyttäjä Access & Activity Tracking',
    'pro_plan_feature6' => 'Luo Tarjous & Pro-forma Laskuja',
    'pro_plan_feature7' => 'Mukauta Laskun Kenttien Otsikoita ja Numerointia',
    'pro_plan_feature8' => 'Option  Attach PDFs  asiakas sähköpostit',
    'resume' => 'Jatka',
    'break_duration' => 'Keskeytä',
    'edit_details' => 'Muokkaa tietoja',
    'work' => 'Työ',
    'timezone_unset' => 'Aseta aikavyöhyke :link',
    'click_here' => 'klikkaa tästä',
    'email_receipt' => 'Lähetä maksukuitti sähköpostilla asiakkaalle',
    'created_payment_emailed_client' => 'Maksu luotu ja lähetetty asiakkaalle onnistuneesti ',
    'add_company' => 'Lisää yritys',
    'untitled' => 'Nimetön',
    'new_company' => 'Uusi yritys',
    'associated_accounts' => 'Tilit onnistuneesti linkitetty',
    'unlinked_account' => 'Tilien linkitys poistettu onnistuneesti',
    'login' => 'Kirjaudu sisään',
    'or' => 'tai',
    'email_error' => 'Ongelma sähköpostin lähetyksessä',
    'confirm_recurring_timing' => 'Huom: sähköpostit lähetetään tasatunnein',
    'confirm_recurring_timing_not_sent' => 'Huom: laskut on luotu at  start of  hour.',
    'payment_terms_help' => 'Asettaa <b>eräpäivään</b> vakioasetuksen',
    'unlink_account' => 'Poista tilin linkitys',
    'unlink' => 'Poista linkitys',
    'show_address' => 'Näytä osoite',
    'show_address_help' => 'Vaadi asiakasta täyttämään laskutusosoite',
    'update_address' => 'Päivitä osoite',
    'update_address_help' => 'Päivitä asiakkaan osoite annetuilla tiedoilla',
    'times' => 'Ajat',
    'set_now' => 'Aseta nykyhetkeen',
    'dark_mode' => 'Tumma tila',
    'dark_mode_help' => 'Käyttää tummaa taustaväriä sivupalkeissa',
    'add_to_invoice' => 'Lisää laskulle :invoice',
    'create_new_invoice' => 'Luo uusi lasku',
    'task_errors' => 'Ole hyvä ja korjaa päällekäiset ajat',
    'from' => 'Lähettäjä',
    'to' => 'Vastaanottaja',
    'font_size' => 'Fontin koko',
    'primary_color' => 'Pääväri',
    'secondary_color' => 'Apuväri',
    'customize_design' => 'Mukauta muotoilua',
    'content' => 'Sisältö',
    'styles' => 'Tyylit',
    'defaults' => 'Oletusasetukset',
    'margins' => 'Marginaalit',
    'header' => 'Ylätunniste',
    'footer' => 'Alatunniste',
    'custom' => 'Mukautettu',
    'invoice_to' => 'Laskutettava',
    'invoice_no' => 'Laskun numero',
    'quote_no' => 'Tarjouksen numero',
    'recent_payments' => 'Viimeisimmät maksut',
    'outstanding' => 'Maksamattomat laskut',
    'manage_companies' => 'Hallitse yrityksiä',
    'total_revenue' => 'Kokonaistulot',
    'current_user' => 'Nykyinen käyttäjä',
    'new_recurring_invoice' => 'Uusi toistuva lasku',
    'recurring_invoice' => 'Toistuva lasku',
    'new_recurring_quote' => 'Uusi toistuva tarjous',
    'recurring_quote' => 'Toistuva tarjous',
    'recurring_too_soon' => 'On liian aikaista luoda uutta toistuvaa laskua. Se on ajastettu päivään :päivämäärä',
    'created_by_invoice' => 'Luotu laskulla :invoice',
    'primary_user' => 'Pääasiallinen käyttäjä',
    'help' => 'Ohje',
    'customize_help' => '<p>We use :pdfmake_link  define  lasku designs declaratively. The pdfmake :playground_link provides  great way  see  library in action.</p>
                        <p>If you need help figuring something out post  question  our :forum_link with  design you\'re using.</p>',
    'playground' => 'playground',
    'support_forum' => 'support forum',
    'invoice_due_date' => 'Eräpäivä',
    'quote_due_date' => 'Voimassa',
    'valid_until' => 'Voimassa',
    'reset_terms' => 'Nollaa ehdot',
    'reset_footer' => 'Nollaa alatunniste',
    'invoice_sent' => ':count lasku lähetetty',
    'invoices_sent' => ':count laskua lähetetty',
    'status_draft' => 'Luonnos',
    'status_sent' => 'Lähetetty',
    'status_viewed' => 'Nähty',
    'status_partial' => 'Osittainen',
    'status_paid' => 'Maksettu',
    'status_unpaid' => 'Maksamaton',
    'status_all' => 'Kaikki',
    'show_line_item_tax' => 'Näytä <b>laskurivien vero rivillä</b>',
    'iframe_url' => 'Verkkosivu',
    'iframe_url_help1' => 'Kopioi seuraava koodi sivustolle.',
    'iframe_url_help2' => 'Voi testata ominaisuutta painamalla \'Katso asiakkaana\' laskulla',
    'auto_bill' => 'Automaattinen laskutus',
    'military_time' => '24 tunnin aika',
    'last_sent' => 'Viimeksi lähetetty',
    'reminder_emails' => 'Muistutussähköpostit',
    'quote_reminder_emails' => 'Tarjous muistutus sähköpostit',
    'templates_and_reminders' => 'Pohjat ja muistutukset',
    'subject' => 'Otsikko',
    'body' => 'Sisältö',
    'first_reminder' => 'Ensimmäinen muistutus',
    'second_reminder' => 'Toinen muistutus',
    'third_reminder' => 'Kolmas muistutus',
    'num_days_reminder' => 'Päivää eräpäivän jälkeen',
    'reminder_subject' => 'Muistutus: Lasku :invoice yritykseltä :tili',
    'reset' => 'Nollaa',
    'invoice_not_found' => 'Pyydettyä laskua ei ole saatavilla',
    'referral_program' => 'Referral Program',
    'referral_code' => 'Referral URL',
    'last_sent_on' => 'Viimeksi lähetetty :päivämäärä',
    'page_expire' => 'Tämä sivu vanhenee pian, :click_here jatkaaksesi',
    'upcoming_quotes' => 'Tulevat tarjoukset',
    'expired_quotes' => 'Vanhentuneet tarjoukset',
    'sign_up_using' => 'Rekisteröidy käyttämällä',
    'invalid_credentials' => 'Kirjautumistiedot eivät täsmää tietojemme kanssa',
    'show_all_options' => 'Näytä kaikki asetukset',
    'user_details' => 'Käyttäjätiedot',
    'oneclick_login' => 'Yhdistetty tili',
    'disable' => 'Poista käytöstä',
    'invoice_quote_number' => 'Lasku- ja tarjousnumerot',
    'invoice_charges' => 'Laskutuslisä',
    'notification_invoice_bounced' => 'Laskun :invoice lähetys asiakkaalle :kontakti epäonnistui',
    'notification_invoice_bounced_subject' => 'Laskun :invoice lähetys epäonnistui',
    'notification_quote_bounced' => 'Tarjouksen :invoice lähetys asiakkaalle :invoice epäonnistui',
    'notification_quote_bounced_subject' => 'Tarjouksen :invoice lähetys epäonnistui',
    'custom_invoice_link' => 'Mukautettu laskulinkki',
    'total_invoiced' => 'Laskutettu yhteensä',
    'open_balance' => 'Avoin saldo',
    'verify_email' => 'Ole hyvä ja käytä linkkiä tilin varmennussähköpostissa vahvistaaksesi sähköpostiosoitteesi.',
    'basic_settings' => 'Perusasetukset',
    'pro' => 'Pro',
    'gateways' => 'Maksuyhdyskäytävät',
    'next_send_on' => 'Lähetä seuraava: :päivämäärä',
    'no_longer_running' => 'Tätä laskua ei ole ajastettu',
    'general_settings' => 'Yleiset asetukset',
    'customize' => 'Mukauta',
    'oneclick_login_help' => 'Yhdistä tili salasanattomaan sisäänkirjautumiseen',
    'referral_code_help' => 'Ansaitse rahaa jakamalla ohjelmaamme verkossa',
    'enable_with_stripe' => 'Ota käyttöön | Tarvitsee Stripen',
    'tax_settings' => 'Veroasetukset',
    'create_tax_rate' => 'Lisää verokanta',
    'updated_tax_rate' => 'Verokanta päivitetty onnistuneesti',
    'created_tax_rate' => 'Verokanta luotu onnistuneesti',
    'edit_tax_rate' => 'Muokkaa verokantaa',
    'archive_tax_rate' => 'Arkistoi verokanta',
    'archived_tax_rate' => 'Verokanta arkistoitu onnistuneesti',
    'default_tax_rate_id' => 'Oletus verokanta',
    'tax_rate' => 'Verokanta',
    'recurring_hour' => 'Toistuva tunti',
    'pattern' => 'Kaava',
    'pattern_help_title' => 'Kaavan ohje',
    'pattern_help_1' => 'Luo mukautettuja numeroita asettamalla kaava',
    'pattern_help_2' => 'Käytössä olevat muuttujat:',
    'pattern_help_3' => 'Esimerkiksi :esimerkki muuttuu muotoon :arvo',
    'see_options' => 'Näytä asetukset',
    'invoice_counter' => 'Laskun laskuri',
    'quote_counter' => 'Tarjouksen laskuri',
    'type' => 'Tyyppi',
    'activity_1' => ':käyttäjä loi asiakkaan :client',
    'activity_2' => ':käyttäjä arkistoi asiakkaan :client',
    'activity_3' => ':käyttäjä poisti asiakkaan :client',
    'activity_4' => ':käyttäjä loi laskun :invoice',
    'activity_5' => ':käyttäjä päivitti laskun :invoice',
    'activity_6' => ':käyttäjä emailed lasku :lasku for :asiakas   :kontakti',
    'activity_7' => ':kontakti katsoi lasku :lasku for :asiakas',
    'activity_8' => ':käyttäjä arkistoi laskun :invoice',
    'activity_9' => ':käyttäjä poisti laskun :invoice',
    'activity_10' => ':kontakti entered maksu :maksu for :payment_amount on lasku :lasku for :asiakas',
    'activity_11' => ':käyttäjä päivitti maksun :maksu',
    'activity_12' => ':käyttäjä arkistoi maksun :maksu',
    'activity_13' => ':käyttäjä poisti maksun :maksu',
    'activity_14' => ':käyttäjä syötti :luotto hyvityksen',
    'activity_15' => ':käyttäjä päivitti :luotto hyvityksen',
    'activity_16' => ':käyttäjä arkistoi :luotto hyvityksen',
    'activity_17' => ':käyttäjä poisti :luotto hyvityksen',
    'activity_18' => ':user loi tarjouksen :quote',
    'activity_19' => ':user päivitti tarjouksen :quote',
    'activity_20' => ':user lähetti sähköpostitse tarjouksen :quote asiakkaan :client yhteyshenkilölle :contact',
    'activity_21' => ':contact luki tarjouksen :quote',
    'activity_22' => ':user arkistoi tarjouksen :quote',
    'activity_23' => ':user poisti tarjouksen :quote',
    'activity_24' => ':user palautti tarjouksen :quote',
    'activity_25' => ':käyttäjä palautti laskun :invoice',
    'activity_26' => ':käyttäjä palautti asiakkaan :client',
    'activity_27' => ':käyttäjä palautti maksun :maksu',
    'activity_28' => ':käyttäjä palautti hyvityksen :luotto',
    'activity_29' => ':contact hyväksyi tarjouksen :quote asiakkaalle :client',
    'activity_30' => ':käyttäjä loi kauppiaan :vendor',
    'activity_31' => ':käyttäjä arkistoi kauppiaan :vendor',
    'activity_32' => ':käyttäjä poisti kauppiaan :vendor',
    'activity_33' => ':käyttäjä palautti kauppiaan :vendor',
    'activity_34' => ':käyttäjä loi kulun :kulu',
    'activity_35' => ':käyttäjä arkistoi kulun :kulu',
    'activity_36' => ':käyttäjä poisti kulun :kulu',
    'activity_37' => ':käyttäjä palautti kulun :kulu',
    'activity_42' => ':käyttäjä loi tehtävän :tehtävä',
    'activity_43' => ':käyttäjä päivitti tehtävän :tehtävä',
    'activity_44' => ':käyttäjä arkistoi tehtävän :tehtävä',
    'activity_45' => ':käyttäjä poisti tehtävän :tehtävä',
    'activity_46' => ':käyttäjä palautti tehtävän :tehtävä',
    'activity_47' => ':käyttäjä päivitti kulun :kulu',
    'activity_48' => ':käyttäjä päivitti tehtävän :tiketti',
    'activity_49' => ':käyttäjä sulki tiketin :tiketti',
    'activity_50' => ':käyttäjä mergesi tiketin :tiketti',
    'activity_51' => ':käyttäjä jakoi tiketin :tiketti',
    'activity_52' => ':kontakti avasi tiketin :tiketti',
    'activity_53' => ':kontakti reopened tiketti :tiketti',
    'activity_54' => ':käyttäjä reopened tiketti :tiketti',
    'activity_55' => ':kontakti vastasi tiketti :tiketti',
    'activity_56' => ':käyttäjä katsoi tiketti :tiketti',

    'payment' => 'Maksu',
    'system' => 'Järjestelmä',
    'signature' => 'Sähköpostiallekirjoitus',
    'default_messages' => 'Vakioviestit',
    'quote_terms' => 'Tarjouksen ehdot',
    'default_quote_terms' => 'Tarjouksen vakioehdot',
    'default_invoice_terms' => 'Laskun vakioehdot',
    'default_invoice_footer' => 'Laskun vakioalatunniste',
    'quote_footer' => 'Tarjouksen alatunniste',
    'free' => 'Ilmainen',
    'quote_is_approved' => 'Hyväksytty onnistuneesti',
    'apply_credit' => 'Käytä luottoa',
    'system_settings' => 'Järjestelmäasetukset',
    'archive_token' => 'Arkistoi token',
    'archived_token' => 'Token arkistoitu onnistuneesti ',
    'archive_user' => 'Arkistoi käyttäjä',
    'archived_user' => 'Käyttäjä arkistoitu onnistuneesti',
    'archive_account_gateway' => 'Poista maksunvälittäjä',
    'archived_account_gateway' => 'Yhdyskäytävä arkistoitu onnistuneesti',
    'archive_recurring_invoice' => 'Arkistoi toistuva lasku',
    'archived_recurring_invoice' => 'Toistuva lasku arkistoitu onnistuneesti',
    'delete_recurring_invoice' => 'Poista toistuva lasku',
    'deleted_recurring_invoice' => 'Toistuva lasku poistettu onnistuneesti',
    'restore_recurring_invoice' => 'Palauta toistuva lasku',
    'restored_recurring_invoice' => 'Toistuva lasku palautettu onnistuneesti',
    'archive_recurring_quote' => 'Arkistoi toistuva tarjous',
    'archived_recurring_quote' => 'Onnistuneesti arkistoitu toistuva tarjous',
    'delete_recurring_quote' => 'Poista toistuva tarjous',
    'deleted_recurring_quote' => 'Onnistuneesti poistettu toistuva tarjous',
    'restore_recurring_quote' => 'Palauta toistuva tarjous',
    'restored_recurring_quote' => 'Onnistuneesti palautettu toistuva tarjous',
    'archived' => 'Arkistoitu',
    'untitled_account' => 'Nimetön yritys',
    'before' => 'Ennen',
    'after' => 'Jälkeen',
    'reset_terms_help' => 'Palauta tilin vakioehtoihin',
    'reset_footer_help' => 'Palauta tilin vakioalatunnisteeseen',
    'export_data' => 'Vie tietoja',
    'user' => 'Käyttäjä',
    'country' => 'Maa',
    'include' => 'Sisällytä',
    'logo_too_large' => 'Logosi on :koko. Paremman PDF-suorituskyvyn takaamiseksi suosittelemme käyttämään alle 200KB kokoista kuvatiedostoa',
    'import_freshbooks' => 'Tuo FreshBooks-palvelusta',
    'import_data' => 'Tuo tietoja',
    'source' => 'Lähde',
    'csv' => 'CSV',
    'client_file' => 'Asiakastiedosto',
    'invoice_file' => 'Laskutiedosto',
    'task_file' => 'Tehtävätiedosto',
    'no_mapper' => 'ei valid mapping  tiedosto',
    'invalid_csv_header' => 'Virheellinen CSV-otsikointi',
    'client_portal' => 'Asiakasportaali',
    'admin' => 'Ylläpito',
    'disabled' => 'Pois käytöstä',
    'show_archived_users' => 'Näytä arkistoidut käyttäjät',
    'notes' => 'Viestit',
    'invoice_will_create' => 'lasku  luotu',
    'invoices_will_create' => 'laskut luodaan',
    'failed_to_import' => 'The following records failed  tuonti, they either already exist tai on missing required fields.',
    'publishable_key' => 'Julkinen avain',
    'secret_key' => 'Salainen avain',
    'missing_publishable_key' => 'aseta sinun Stripe publishable avain for  improved checkout process',
    'email_design' => 'Sähköpostin muotoilu',
    'due_by' => 'Eräpäivä :päivämäärä',
    'enable_email_markup' => 'Ota käyttöön merkintä',
    'enable_email_markup_help' => 'Tee asiakkaillesi helpommaksi maksaa laskusi ottamalla käyttöön schema.org -merkintä  sähköposteissasi.',
    'template_help_title' => 'pohjat Help',
    'template_help_1' => 'Käytössä olevat muuttujat:',
    'email_design_id' => 'Sähköpostin tyyli',
    'email_design_help' => 'Make sinun sähköpostit look more professional  HTML layouts.',
    'plain' => 'Yksinkertainen',
    'light' => 'Vaalea',
    'dark' => 'Tumma',
    'industry_help' => 'Tietoa käytetään, jotta voidaan tuottaa vertailutietoa keskimääräisistä yritysten koosta samalla toimialalla.',
    'subdomain_help' => 'Aseta  alidomain tai näytä  lasku omalla verkkosivullasi.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'määritä  etuliite tai use  custom pattern  dynamically set  lasku numero.',
    'quote_number_help' => 'Määritä etuliite tai käytä mukautettua muotoa asettaaksesi dynaamisesti tarjousnumerot.',
    'custom_client_fields_helps' => 'Lisää  kenttä luotaessa  asiakas ja valinnaisesti näytä otsikko ja arvo PDF:ssä.',
    'custom_account_fields_helps' => 'Lisää  otsikko ja arvo Yrityksen tiedot -kappaleessa PDF:ssä.',
    'custom_invoice_fields_helps' => 'Lisää  kenttä luotaessa lasku  lasku ja valinnaisesti näytä  otsikko ja arvo  PDF:ssä.',
    'custom_invoice_charges_helps' => 'lisää  kenttä when creating  lasku ja include  charge in  lasku subtotals.',
    'token_expired' => 'Validation token was expired.  try again.',
    'invoice_link' => 'Laskun linkki',
    'button_confirmation_message' => 'Klikkaa vahvistaksesi sähköpostiosoitteesi.',
    'confirm' => 'Vahvista',
    'email_preferences' => 'Sähköpostiasetukset',
    'created_invoices' => 'onnistuneesti luotu :count lasku(s)',
    'next_invoice_number' => 'The next lasku numero is :numero.',
    'next_quote_number' => 'Seuraavan tarjouksen numero on :number.',
    'days_before' => 'päivää ennen',
    'days_after' => 'päivää jälkeen',
    'field_due_date' => 'eräpäivä',
    'field_invoice_date' => 'Laskun päiväys',
    'schedule' => 'Aikataulu',
    'email_designs' => 'Sähköpostin mallit',
    'assigned_when_sent' => 'Assigned when lähettää',
    'white_label_purchase_link' => 'Purchase  white label lisenssi',
    'expense' => 'Kulu',
    'expenses' => 'Kulut',
    'new_expense' => 'Lisää kulu',
    'enter_expense' => 'Lisää kulu',
    'vendors' => 'Kauppiaat',
    'new_vendor' => 'Uusi kauppias',
    'payment_terms_net' => 'Netto',
    'vendor' => 'Kauppias',
    'edit_vendor' => 'Muokkaa kauppiasta',
    'archive_vendor' => 'Arkistoi kauppias',
    'delete_vendor' => 'Poista kauppias',
    'view_vendor' => 'Näytä kauppias',
    'deleted_expense' => 'Kulu poistettu onnistuneesti',
    'archived_expense' => 'Kulu arkistoitu onnistuneesti',
    'deleted_expenses' => 'onnistuneesti poistettu kulut',
    'archived_expenses' => 'onnistuneesti arkistoitu kulut',
    'expense_amount' => 'kulu määrä',
    'expense_balance' => 'kulu Balance',
    'expense_date' => 'Kulun päivämäärä',
    'expense_should_be_invoiced' => 'Should this kulu be invoiced?',
    'public_notes' => 'Julkiset muistiinpanot',
    'invoice_amount' => 'Lasku määrä',
    'exchange_rate' => 'Exchange Rate',
    'yes' => 'Kyllä',
    'no' => 'Ei',
    'should_be_invoiced' => 'Pitäisi laskuttaa',
    'view_expense' => 'Näytä kulu # :kulu',
    'edit_expense' => 'muokkaa kulu',
    'archive_expense' => 'Arkistoi kulu',
    'delete_expense' => 'Poista kulu',
    'view_expense_num' => 'kulu # :kulu',
    'updated_expense' => 'onnistuneesti päivitetty kulu',
    'created_expense' => 'onnistuneesti luotu kulu',
    'enter_expense' => 'Lisää kulu',
    'view' => 'Näytä',
    'restore_expense' => 'palauta kulu',
    'invoice_expense' => 'Lasku kulu',
    'expense_error_multiple_clients' => 'The kulut ei voi kuulua  eri asiakkaat',
    'expense_error_invoiced' => 'kulu on already been invoiced',
    'convert_currency' => 'Muunna valuutta',
    'num_days' => 'Päivien määrä',
    'create_payment_term' => 'Luo maksuehto',
    'edit_payment_terms' => 'Muokkaa maksuaikaa',
    'edit_payment_term' => 'Muokkaa maksuaikaa',
    'archive_payment_term' => 'Arkistoi maksuehto',
    'recurring_due_dates' => 'toistuva Lasku Due Dates',
    'recurring_due_date_help' => '<p>automaattisesti sets  erä päivämäärä for  lasku.</p>
        <p>laskut on  kuukaisittain tai vuosittain cycle set  be erä on tai before  day they on luotu  erä  next kuukausi. laskut set  be erä on  29th tai 30th in kuukautta that don\'t have that day  erä  last day of  kuukausi.</p>
        <p>laskut on  viikottain cycle set  be erä on  day of  week they on luotu  erä  next week.</p>
        <p>For esimerkki:</p>
        <ul>
          <li>tänään is  15th, erä päivämäärä is 1st of  kuukausi. The erä päivämäärä should likely be  1st of  next kuukausi.</li>
          <li>tänään is  15th, erä päivämäärä is  last day of  kuukausi. The erä päivämäärä will be  last day of  this kuukausi.
</li>
          <li>tänään is  15th, erä päivämäärä is  15th day of  kuukausi. The erä päivämäärä will be  15th day of <strong>next</strong> kuukausi.
</li>
          <li>tänään is  Friday, erä päivämäärä is  1st Friday after. The erä päivämäärä  next Friday, not today.
</li>
        </ul>',
    'due' => 'Due',
    'next_due_on' => 'Seuraava eräpäivä: :päivämäärä',
    'use_client_terms' => 'Käytä asiakkaan maksuehtoa',
    'day_of_month' => ':ordinal day  kuukausi',
    'last_day_of_month' => 'viime day  kuukausi',
    'day_of_week_after' => ':ordinal :day after',
    'sunday' => 'sunnuntai',
    'monday' => 'Maanantai',
    'tuesday' => 'Tiistai',
    'wednesday' => 'Keskiviikko',
    'thursday' => 'Torstai',
    'friday' => 'Perjantai',
    'saturday' => 'Lauantai',
    'header_font_id' => 'Otsikon kirjasin',
    'body_font_id' => 'Bodyn kirjasin',
    'color_font_help' => 'Huom:  primary color ja fonts on also used in  asiakas portal ja custom sähköposti designs.',
    'live_preview' => 'Näytä esikatselu',
    'invalid_mail_config' => 'Unable  send sähköposti,  tarkista that  mail asetus on oikein.',
    'invoice_message_button' => 'Nähdäksesi laskun :amount, paina allaolevaa nappia.',
    'quote_message_button' => 'Nähdäksesi tarjouksen :amount, paina allaolevaa nappia.',
    'payment_message_button' => 'Kiitos summan :amount maksustasi.',
    'payment_type_direct_debit' => 'Direct Debit',
    'bank_accounts' => 'Luottokortit & pankit',
    'add_bank_account' => 'Lisää pankkitili',
    'setup_account' => 'Määritä tili',
    'import_expenses' => 'Tuo kulut',
    'bank_id' => 'Pankki',
    'integration_type' => 'Integraation tyyppi',
    'updated_bank_account' => 'Pankkitili on onnistuneesti päivitetty',
    'edit_bank_account' => 'Muokkaa pankkitiliä',
    'archive_bank_account' => 'Arkistoi pankkitili',
    'archived_bank_account' => 'onnistuneesti arkistoitu pankkitili',
    'created_bank_account' => 'Onnistuneesti luotu pankkitili',
    'validate_bank_account' => 'Validate Bank Account',
    'bank_password_help' => 'Huom: sinun salasana is transmitted securely ja never stored on our servers.',
    'bank_password_warning' => 'Warning: sinun salasana may be transmitted in plain text, consider enabling HTTPS.',
    'username' => 'Käyttäjätunnus',
    'account_number' => 'Tilinumero',
    'account_name' => 'Tilin nimi',
    'bank_account_error' => 'Käyttäjätilin tietojen haku epäonnistui,  tarkista kirjautumistunnuksesi.',
    'status_approved' => 'Hyväksytty',
    'quote_settings' => 'Tarjouksen asetukset',
    'auto_convert_quote' => 'Automaattinen muunnos',
    'auto_convert_quote_help' => 'Muunna tarjous automaattisesti laskuksi, kun asiakas on hyväksynyt tarjouksen.',
    'validate' => 'Validoi',
    'info' => 'Info',
    'imported_expenses' => 'Onnistuneesti luotu :count_vendors kauppias(ta) ja :count_expenses kulu(ja)',
    'iframe_url_help3' => 'Huom: jos aiot hyväksyä luottokorttitietoja, suosittelemme vahvasti että otat käyttöön HTTPS:n sivustollasi.',
    'expense_error_multiple_currencies' => 'Kulut eivät voi olla eri valuuttoja.',
    'expense_error_mismatch_currencies' => 'The asiakas\'s currency does not match  kulu currency.',
    'trello_roadmap' => 'Trellon roadmap',
    'header_footer' => 'Header/Footer',
    'first_page' => 'ensimmäinen page',
    'all_pages' => 'All pages',
    'last_page' => 'viime page',
    'all_pages_header' => 'näytä Header on',
    'all_pages_footer' => 'Näytä alatunniste',
    'invoice_currency' => 'Laskun valuutta',
    'enable_https' => 'Suosittelemme vahvasti käyttämään HTTPS:ää hyväksyessäsi luottokorttitietoja verkossa.',
    'quote_issued_to' => 'Tarjous on osoitettu  ',
    'show_currency_code' => 'Currency Code',
    'free_year_message' => 'sinun tili on upgraded    pro plan  yksi year at no cost.',
    'trial_message' => 'sinun tili will receive  free two week trial  our pro plan.',
    'trial_footer' => 'sinun free pro plan trial lasts :count more days, :link  upgrade nyt.',
    'trial_footer_last_day' => 'tämä is  last day  sinun free pro plan trial, :link  upgrade nyt.',
    'trial_call_to_action' => 'aloita Free Trial',
    'trial_success' => 'onnistuneesti enabled two week free pro plan trial',
    'overdue' => 'Yliaika',


    'white_label_text' => 'Purchase  ONE YEAR white label lisenssi for $:hinta  remove  Lasku Ninja branding from  lasku ja asiakas portal.',
    'user_email_footer' => 'To adjust sinun sähköposti notification asetus  visit :link',
    'reset_password_footer' => 'If you did not request this salasana reset  sähköposti our support: :sähköposti',
    'limit_users' => 'Sorry, this will exceed  limit of :limit users',
    'more_designs_self_host_header' => 'Get 6 more lasku designs  just $:hinta',
    'old_browser' => 'Ole hyvä ja käytä  :link',
    'newer_browser' => 'uudempi selain',
    'white_label_custom_css' => ':link hinnalle $:hinta  ottaaksesi käyttöön mukautetun tyylin ja auttaa tukemaan projektiamme.',
    'bank_accounts_help' => 'Yhdistä pankkitili tuodaksesi automaattisesti kulut ja luodaksesi kauppiaat.   Supports American Express ja :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link  remove  Lasku Ninja logo by joining  Pro Plan',
    'pro_plan_remove_logo_link' => 'Napsauta tästä',
    'invitation_status_sent' => 'Lähetetty',
    'invitation_status_opened' => 'Avattu',
    'invitation_status_viewed' => 'Nähty',
    'email_error_inactive_client' => 'sähköpostia ei voi lähettää  passiivisille asiakkaille',
    'email_error_inactive_contact' => 'sähköpostia ei voi lähettää  passiivisille kontakteille',
    'email_error_inactive_invoice' => 'sähköpostia ei voi lähettää  passiivisille laskuille',
    'email_error_inactive_proposal' => 'sähköpostia ei voi lähettää  passiivisille ehdokkaille',
    'email_error_user_unregistered' => ' rekisteröi tilisi  lähettääksesi sähköposteja',
    'email_error_user_unconfirmed' => ' vahvista tilisi  lähettääksesi sähköposteja',
    'email_error_invalid_contact_email' => 'epäkelpo yhteyssähköposti',

    'navigation' => 'Navigaatio',
    'list_invoices' => 'Listaa laskut',
    'list_clients' => 'listaa asiakkaat',
    'list_quotes' => 'Listaa tarjoukset',
    'list_tasks' => 'listaa tehtävät',
    'list_expenses' => 'listaa kulut',
    'list_recurring_invoices' => 'listaa toistuva laskut',
    'list_payments' => 'listaa maksut',
    'list_credits' => 'listaa luotot',
    'tax_name' => 'veronimi',
    'report_settings' => 'raportti asetukset',
    'search_hotkey' => 'oikopolku on/',

    'new_user' => 'Uusi käyttäjä',
    'new_product' => 'Uusi tuote',
    'new_tax_rate' => 'Uusi veromäärä',
    'invoiced_amount' => 'Laskutettu määrä',
    'invoice_item_fields' => 'Laskun nimike-kentät',
    'custom_invoice_item_fields_help' => 'Lisää  kenttä luotaessa laskun nimike  ja näytä otsikko ja arvo PDF:ssä.',
    'recurring_invoice_number' => 'toistuva numero',
    'recurring_invoice_number_prefix_help' => 'määritä  etuliite  be added    lasku numero  toistuva laskut.',

    // Client Passwords
    'enable_portal_password' => 'salasana suojaa laskut',
    'enable_portal_password_help' => 'Mahdollistaa, että voit antaa salasanan jokaiselle yhteyshenkilölle. Jos salasana on asetettu, yhteyshenkilön tulee kirjautua sen avulla sisään voidakseen tarkastella laskuja.',
    'send_portal_password' => 'Generoi automaattisesti',
    'send_portal_password_help' => 'If no salasana is set, yksi  generated ja lähettää with  first lasku.',

    'expired' => 'Vanhentunut',
    'invalid_card_number' => 'Luottokortin numero ei kelpaa.',
    'invalid_expiry' => 'Vanhenemispäivä ei kelpaa.',
    'invalid_cvv' => 'CVV-koodi ei kelpaa.',
    'cost' => 'Hinta',
    'create_invoice_for_sample' => 'Huom: luo ensimmäinen laskusi nähdäksesi esikatselun tässä.',

    // User Permissions
    'owner' => 'Omistaja',
    'administrator' => 'Ylläpitäjä',
    'administrator_help' => 'Allow käyttäjä  manage users, change asetus ja modify kaikki records',
    'user_create_all' => 'luo asiakkaat, laskut, etc.',
    'user_view_all' => 'Näytä kaikki asiakkaat, laskut jne',
    'user_edit_all' => 'muokkaa kaikki asiakkaat, laskut, etc.',
    'gateway_help_20' => ':link rekisteröityäksesi palveluun Sage Pay',
    'gateway_help_21' => ':link rekisteröityäksesi palveluun Sage Pay.',
    'partial_due' => 'Partial Due',
    'restore_vendor' => 'Palauta kauppias',
    'restored_vendor' => 'Onnistuneesti palautettu kauppias',
    'restored_expense' => 'onnistuneesti palautettu kulu',
    'permissions' => 'Oikeudet',
    'create_all_help' => 'Salli käyttäjän luoda ja muokata tallenteita',
    'view_all_help' => 'Salli käyttäjän nähdä tiedot, joita ei ole itse luonut',
    'edit_all_help' => 'Salli käyttäjän muokata tallenteita joita ei ole itse luonut',
    'view_payment' => 'Näytä Maksu',

    'january' => 'Tammikuu',
    'february' => 'Helmikuu',
    'march' => 'Maaliskuu',
    'april' => 'Huhtikuu',
    'may' => 'Toukokuu',
    'june' => 'Kesäkuu',
    'july' => 'Heinäkuu',
    'august' => 'Elokuu',
    'september' => 'Syyskuu',
    'october' => 'Lokakuu',
    'november' => 'Marraskuu',
    'december' => 'Joulukuu',

    // Documents
    'documents_header' => 'Dokumentit:',
    'email_documents_header' => 'Dokumentit:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Tarjouksen asiakirjat',
    'invoice_documents' => 'Laskun asiakirjat',
    'expense_documents' => 'Kulun asiakirjat',
    'invoice_embed_documents' => 'Embed Documents',
    'invoice_embed_documents_help' => 'Sisällytä liitetyt kuvat laskuun.',
    'document_email_attachment' => 'Liitä Dokumentit',
    'ubl_email_attachment' => 'Liitä UBL',
    'download_documents' => 'Lataa asiakirjat (:koko)',
    'documents_from_expenses' => 'Kuluista:',
    'dropzone_default_message' => 'Pudota tiedostot tai napsauta ladataksesi palvelimelle',
    'dropzone_default_message_disabled' => 'Palvelimelle lataus pois käytöstä',
    'dropzone_fallback_message' => 'Selaimesi ei tue raahaa ja pudota latausta palvelimelle.',
    'dropzone_fallback_text' => ' use  fallback form alla  upload sinun files like in  olden days.',
    'dropzone_file_too_big' => 'Tiedosto on liian suuri ({{filesize}}MiB). Maksimi tiedostokoko: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Et voi ladata palvelimelle tätä tiedostotyyppiä.',
    'dropzone_response_error' => 'Server responded with {{statusCode}} koodi.',
    'dropzone_cancel_upload' => 'Peruuta lataus palvelimelle',
    'dropzone_cancel_upload_confirmation' => 'Oletko varma että haluat peruuttaa tämän latauksen palvelimelle?',
    'dropzone_remove_file' => 'Poista tiedosto',
    'documents' => 'Asiakirjat',
    'document_date' => 'Asiakirjan päiväys',
    'document_size' => 'Koko',

    'enable_client_portal' => 'Asiakasportaali',
    'enable_client_portal_help' => 'Näytä/piilota  asiakasportaali.',
    'enable_client_portal_dashboard' => 'Hallintapaneeli',
    'enable_client_portal_dashboard_help' => 'Näytä/piilota  hallintapaneeli-sivu asiakasportaalissa.',

    // Plans
    'account_management' => 'Käyttäjätilin hallinta',
    'plan_status' => 'Plan tila',

    'plan_upgrade' => 'Päivitä',
    'plan_change' => 'Change Plan',
    'pending_change_to' => 'Changes To',
    'plan_changes_to' => ':plan on :päivämäärä',
    'plan_term_changes_to' => ':plan (:ehto) on :päivämäärä',
    'cancel_plan_change' => 'Cancel Change',
    'plan' => 'Plan',
    'expires' => 'Expires',
    'renews' => 'Renews',
    'plan_expired' => ':plan Plan Expired',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Ei koskaan',
    'plan_free' => 'Ilmainen',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Kuukausittain',
    'plan_term_yearly' => 'Vuosittain',
    'plan_term_month' => 'Kuukausi',
    'plan_term_year' => 'Vuosi',
    'plan_price_monthly' => '$:hinta/kuukausi',
    'plan_price_yearly' => '$:hinta/Vuosi',
    'updated_plan' => 'päivitetty plan asetus',
    'plan_paid' => 'Term Started',
    'plan_started' => 'Plan Started',
    'plan_expires' => 'Plan Expires',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'One year enrollment in  Lasku Ninja Pro Plan.',
    'pro_plan_month_description' => 'One kuukausi enrollment in  Lasku Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'One year enrollment in  Lasku Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One kuukausi enrollment in  Lasku Ninja Enterprise Plan.',
    'plan_credit_product' => 'Luotto',
    'plan_credit_description' => 'Hyvitys käyttämättömälle ajalle',
    'plan_pending_monthly' => 'Will switch  kuukaisittain on :päivämäärä',
    'plan_refunded' => 'A hyvitys on issued.',

    'live_preview' => 'Näytä esikatselu',
    'page_size' => 'Page Size',
    'live_preview_disabled' => 'Live preview on pois käytöstä  support selected font',
    'invoice_number_padding' => 'Tyhjä tila',
    'preview' => 'Esikatselu',
    'list_vendors' => 'Listaa kauppiaat',
    'add_users_not_supported' => 'Upgrade    Enterprise plan  lisää additional users  tilisi.',
    'enterprise_plan_features' => 'The Enterprise plan adds support  multiple users ja tiedosto attachments, :link  see  full list  ominaisuudet.',
    'return_to_app' => 'Return To App',


    // Payment updates
    'refund_payment' => 'Hyvitysmaksu',
    'refund_max' => 'Max:',
    'refund' => 'Hyvitys',
    'are_you_sure_refund' => 'Refund selected payments?',
    'status_pending' => 'Odottaa',
    'status_completed' => 'Valmis',
    'status_failed' => 'Epäonnistui',
    'status_partially_refunded' => 'Osittain hyvitetty',
    'status_partially_refunded_amount' => ':amount hyvitetty',
    'status_refunded' => 'Hyvitetty',
    'status_voided' => 'Peruutettu',
    'refunded_payment' => 'Hyvitetty maksu',
    'activity_39' => ':käyttäjä perui :payment_amount maksun :maksu',
    'activity_40' => ':käyttäjä refunded :adjustment  a :payment_amount maksu :maksu',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Tuntematon',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept US bank transfers',
    'stripe_ach_help' => 'ACH support must also be enabled in :link.',
    'ach_disabled' => 'Toinen maksunvälittäjä on jo määritelty suoraveloituksiin.',

    'plaid' => 'Plaid',
    'client_id' => 'Asiakkaan tunniste',
    'secret' => 'Secret',
    'public_key' => 'Julkinen avain',
    'plaid_optional' => '(optional)',
    'plaid_environment_help' => 'When  Stripe test avain is given, Plaid\'s development environment (tartan)  used.',
    'other_providers' => 'Other Providers',
    'country_not_supported' => 'That country ei ole supported.',
    'invalid_routing_number' => 'The routing numero ei ole valid.',
    'invalid_account_number' => 'The tili numero ei ole valid.',
    'account_number_mismatch' => 'The tili numbers do not match.',
    'missing_account_holder_type' => ' valitse  individual tai yritys tili.',
    'missing_account_holder_name' => ' Anna tilin omistajan nimi.',
    'routing_number' => 'Routing numero',
    'confirm_account_number' => 'Confirm Account numero',
    'individual_account' => 'Individual Account',
    'company_account' => 'yritys Account',
    'account_holder_name' => 'Account Holder nimi',
    'add_account' => 'Lisää tili',
    'payment_methods' => 'maksu Methods',
    'complete_verification' => 'Complete Verification',
    'verification_amount1' => 'määrä 1',
    'verification_amount2' => 'määrä 2',
    'payment_method_verified' => 'Verification valmis onnistuneesti',
    'verification_failed' => 'Verification Failed',
    'remove_payment_method' => 'Remove maksu Method',
    'confirm_remove_payment_method' => 'Are you sure you want  remove this maksu method?',
    'remove' => 'Remove',
    'payment_method_removed' => 'Removed maksu method.',
    'bank_account_verification_help' => 'We have made two deposits into tilisi with  description "VERIFICATION". These deposits will take 1-2 business days  appear on sinun statement.  syötä  amounts alla.',
    'bank_account_verification_next_steps' => 'We have made two deposits into tilisi with  description "VERIFICATION". These deposits will take 1-2 business days  appear on sinun statement.
        Once you have  amounts, come back  this maksu methods page ja click "Complete Verification" next    tili.',
    'unknown_bank' => 'Unknown Bank',
    'ach_verification_delay_help' => 'You  able  use  tili after completing verification. Verification usually takes 1-2 business days.',
    'add_credit_card' => 'Lisää luottokortti',
    'payment_method_added' => 'Added maksu method.',
    'use_for_auto_bill' => 'käytä For Autobill',
    'used_for_auto_bill' => 'Autobill maksu Method',
    'payment_method_set_as_default' => 'aseta Autobill maksu method.',
    'activity_41' => ':payment_amount maksu (:maksu) failed',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'You must :link.',
    'stripe_webhook_help_link_text' => 'lisää this URL as  endpoint at Stripe',
    'gocardless_webhook_help_link_text' => 'lisää this URL as  endpoint in GoCardless',
    'payment_method_error' => 'Oli  virhe adding sinun maksu methd.  try again later.',
    'notification_invoice_payment_failed_subject' => 'maksu failed  Lasku :lasku',
    'notification_invoice_payment_failed' => 'Asiakkaan maksu :asiakas laskulle :lasku epäonnistui. Maksu on merkitty epäonnistuneeksi ja :amount on lisätty asiakkaan velkasaldoon.',
    'link_with_plaid' => 'linkki Account Instantly  Plaid',
    'link_manually' => 'linkki Manually',
    'secured_by_plaid' => 'Secured by Plaid',
    'plaid_linked_status' => 'sinun bank tili at :bank',
    'add_payment_method' => 'Lisää maksutapa',
    'account_holder_type' => 'Account Holder Type',
    'ach_authorization' => 'I authorize :yritys  use my bank tili  future payments ja, jos necessary, electronically luotto my tili  oikein erroneous debits. I understand that I may peruuta this authorization at any time by removing  maksu method tai by contacting :sähköposti.',
    'ach_authorization_required' => 'You must consent  ACH transactions.',
    'off' => 'Off',
    'opt_in' => 'Opt-in',
    'opt_out' => 'Opt-out',
    'always' => 'Always',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'Manage automaattinen-bill',
    'enabled' => 'Enabled',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Enable PayPal payments through BrainTree',
    'braintree_paypal_disabled_help' => 'PayPal maksunvälittäjänä prosessoi PayPal maksut',
    'braintree_paypal_help' => 'You must also :link.',
    'braintree_paypal_help_link_text' => 'link PayPal  sinun BrainTree tili',
    'token_billing_braintree_paypal' => 'Tallenna maksun tiedot',
    'add_paypal_account' => 'Lisää PayPal-tili',


    'no_payment_method_specified' => 'Maksutapaa ei ole määritelty',
    'chart_type' => 'Chart Type',
    'format' => 'Format',
    'import_ofx' => 'Import OFX',
    'ofx_file' => 'OFX File',
    'ofx_parse_failed' => 'Failed  parse OFX tiedosto',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Sign up  WePay',
    'use_another_provider' => 'käytä another provider',
    'company_name' => 'yritys nimi',
    'wepay_company_name_help' => 'tämä will appear on asiakas\'s luotto card statements.',
    'wepay_description_help' => 'The purpose  this tili.',
    'wepay_tos_agree' => 'I agree  the :link.',
    'wepay_tos_link_text' => 'WePay Terms  Service',
    'resend_confirmation_email' => 'Resend Confirmation Email',
    'manage_account' => 'Manage Account',
    'action_required' => 'Action Required',
    'finish_setup' => 'Finish Setup',
    'created_wepay_confirmation_required' => ' tarkista sinun sähköposti ja vahvista sinun sähköposti osoite  WePay.',
    'switch_to_wepay' => 'Switch  WePay',
    'switch' => 'Switch',
    'restore_account_gateway' => 'Palauta maksunvälittäjä',
    'restored_account_gateway' => 'onnistuneesti palautettu maksunvälittäjä',
    'united_states' => 'Yhdysvallat',
    'canada' => 'Kanada',
    'accept_debit_cards' => 'Accept Debit Cards',
    'debit_cards' => 'Debit Cards',

    'warn_start_date_changed' => 'The next lasku  lähettää on  uusi start päivämäärä.',
    'warn_start_date_changed_not_sent' => 'The next lasku  luotu on  uusi start päivämäärä.',
    'original_start_date' => 'Original start päivämäärä',
    'new_start_date' => 'uusi start päivämäärä',
    'security' => 'Security',
    'see_whats_new' => 'See what\'s uusi in v:versio',
    'wait_for_upload' => ' wait for  dokumentti upload  complete.',
    'upgrade_for_permissions' => 'Upgrade  our Enterprise plan  enable permissions.',
    'enable_second_tax_rate' => 'Enable specifying a <b>second tax rate</b>',
    'payment_file' => 'Maksu tiedosto',
    'expense_file' => 'kulu File',
    'product_file' => 'Tuote tiedosto',
    'import_products' => 'Import tuotteet',
    'products_will_create' => 'tuotteet  luotu',
    'product_key' => 'Tuote',
    'created_products' => 'Onnistuneesti luotu/päivitetty :count tuote(tta)',
    'export_help' => 'käytä JSON jos you plan  tuonti  data into Lasku Ninja.<br/>The tiedosto includes asiakkaat, tuotteet, laskut, quotes ja payments.',
    'selfhost_export_help' => '<br/>We recommend using mysqldump  create  full varmuuskopio.',
    'JSON_file' => 'JSON File',

    'view_dashboard' => 'Näytä Hallintapaneeli',
    'client_session_expired' => 'Session Expired',
    'client_session_expired_message' => 'sinun session on expired.  click  link in sinun sähköposti again.',

    'auto_bill_notification' => 'tämä lasku will automatically be billed  sinun :payment_method on tiedosto on :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'bank tili',
    'auto_bill_payment_method_credit_card' => 'luotto card',
    'auto_bill_payment_method_paypal' => 'PayPal tili',
    'auto_bill_notification_placeholder' => 'tämä lasku will automatically be billed  sinun luotto card on tiedosto on  erä päivämäärä.',
    'payment_settings' => 'Maksujen asetukset',

    'on_send_date' => 'On send päivämäärä',
    'on_due_date' => 'On erä päivämäärä',
    'auto_bill_ach_date_help' => 'ACH will always auto bill on  erä päivämäärä.',
    'warn_change_auto_bill' => 'Due  NACHA rules, muutokset  this lasku may prevent ACH auto bill.',

    'bank_account' => 'Bank Account',
    'payment_processed_through_wepay' => 'ACH payments  processed using WePay.',
    'wepay_payment_tos_agree' => 'I agree    WePay :terms ja :privacy_policy.',
    'privacy_policy' => 'Privacy Policy',
    'wepay_payment_tos_agree_required' => 'You must agree    WePay Terms  Service ja Privacy Policy.',
    'ach_email_prompt' => 'Ole hyvä ja anna sähköpostiosoitteesi:',
    'verification_pending' => 'Verification Pending',

    'update_font_cache' => ' force refresh  page  update  font cache.',
    'more_options' => 'Lisää valintoja',
    'credit_card' => 'Luottokortti',
    'bank_transfer' => 'Pankkisiirto',
    'no_transaction_reference' => 'We did not recieve  maksu tapahtuma reference from  maksunvälittäjä.',
    'use_bank_on_file' => 'käytä Bank on File',
    'auto_bill_email_message' => 'tämä lasku will automatically be billed    maksu method on tiedosto on  erä päivämäärä.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Added :päivämäärä',
    'failed_remove_payment_method' => 'Failed  remove  maksu method',
    'gateway_exists' => 'Tämä maksunvälittäjä on jo olemassa',
    'manual_entry' => 'Manual entry',
    'start_of_week' => 'Viikon ensimmäinen päivä',

    // Frequencies
    'freq_inactive' => 'Inactive',
    'freq_daily' => 'päivittäin',
    'freq_weekly' => 'viikoittain',
    'freq_biweekly' => 'jokatoinen viikko',
    'freq_two_weeks' => 'Kaksi viikkoa',
    'freq_four_weeks' => 'neljä viikkoa',
    'freq_monthly' => 'Kuukausittain',
    'freq_three_months' => 'kolme kuukautta',
    'freq_four_months' => 'neljä kuukautta',
    'freq_six_months' => 'Six kuukautta',
    'freq_annually' => 'Vuosittain',
    'freq_two_years' => 'Kaksi vuotta',

    // Payment types
    'payment_type_Apply Credit' => 'Käytä luottoa',
    'payment_type_Bank Transfer' => 'Pankkisiirto',
    'payment_type_Cash' => 'Cash',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa kortti',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover kortti',
    'payment_type_Diners Card' => 'Diners kortti',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'luotto kortti Other',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Taloushallinto & Lakiasiat',
    'industry_Advertising' => 'Markkinointi',
    'industry_Aerospace' => 'Ilmailu',
    'industry_Agriculture' => 'Maatalous',
    'industry_Automotive' => 'Ajoneuvot',
    'industry_Banking & Finance' => 'Pankki & Rahoitus',
    'industry_Biotechnology' => 'Bioteknologia',
    'industry_Broadcasting' => 'Radio, TV ym. lähetykset',
    'industry_Business Services' => 'Yritysten palvelut',
    'industry_Commodities & Chemicals' => 'Hyödykkeet & Kemikaalit',
    'industry_Communications' => 'Viestintä',
    'industry_Computers & Hightech' => 'Tietokoneet & Hightech',
    'industry_Defense' => 'Puolustus',
    'industry_Energy' => 'Energia',
    'industry_Entertainment' => 'Viihde',
    'industry_Government' => 'Julkinen sektori',
    'industry_Healthcare & Life Sciences' => 'Terveydenhuolto & Life Sciences',
    'industry_Insurance' => 'Vakuutus',
    'industry_Manufacturing' => 'Valmistus',
    'industry_Marketing' => 'Markkinointi',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Apteekit ja lääkeala',
    'industry_Professional Services & Consulting' => 'Vaativat ammattilaispalvelut & konsultointi',
    'industry_Real Estate' => 'Kiinteistönvälitys',
    'industry_Restaurant & Catering' => 'Ravintolat ja pitopalvelut',
    'industry_Retail & Wholesale' => 'Vähittäis & Tukkukauppa',
    'industry_Sports' => 'Urheilu',
    'industry_Transportation' => 'Kuljetus',
    'industry_Travel & Luxury' => 'Matkailu & Luksus',
    'industry_Other' => 'Muu',
    'industry_Photography' => 'Valokuvaus',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua ja Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgium',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia ja Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Kanada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Province  China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo,  Democratic Republic  the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Faroe Islands',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia ja  South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'France',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germany',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Greece',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island ja McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican kaupunki State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungary',
    'country_Iceland' => 'Iceland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuania',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius ja Saba',
    'country_New Caledonia' => 'uusi Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'uusi Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua uusi Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Poland',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russian Federation',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension ja Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts ja Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre ja Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent ja  Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome ja Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spain',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard ja Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad ja Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turkey',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks ja Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia,  former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle  Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'Yhdysvallat',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis ja Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Croatian',
    'lang_Czech' => 'Czech',
    'lang_Danish' => 'Danish',
    'lang_Dutch' => 'Dutch',
    'lang_English' => 'English',
    'lang_French' => 'French',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'German',
    'lang_Italian' => 'Italian',
    'lang_Japanese' => 'Japanese',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norwegian',
    'lang_Polish' => 'Polish',
    'lang_Spanish' => 'Spanish',
    'lang_Spanish - Spain' => 'Spanish - Spain',
    'lang_Swedish' => 'Swedish',
    'lang_Albanian' => 'Albanian',
    'lang_Greek' => 'Greek',
    'lang_English - United Kingdom' => 'English - United Kingdom',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Slovenian',
    'lang_Finnish' => 'Suomi',
    'lang_Romanian' => 'Romanian',
    'lang_Turkish - Turkey' => 'Turkish - Turkey',
    'lang_Portuguese - Brazilian' => 'Portuguese - Brazilian',
    'lang_Portuguese - Portugal' => 'Portuguese - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Taloushallinto & Lakiasiat',
    'industry_Advertising' => 'Markkinointi',
    'industry_Aerospace' => 'Ilmailu',
    'industry_Agriculture' => 'Maatalous',
    'industry_Automotive' => 'Ajoneuvot',
    'industry_Banking & Finance' => 'Pankki & Rahoitus',
    'industry_Biotechnology' => 'Bioteknologia',
    'industry_Broadcasting' => 'Radio, TV ym. lähetykset',
    'industry_Business Services' => 'Yritysten palvelut',
    'industry_Commodities & Chemicals' => 'Hyödykkeet & Kemikaalit',
    'industry_Communications' => 'Viestintä',
    'industry_Computers & Hightech' => 'Tietokoneet & Hightech',
    'industry_Defense' => 'Puolustus',
    'industry_Energy' => 'Energia',
    'industry_Entertainment' => 'Viihde',
    'industry_Government' => 'Julkinen sektori',
    'industry_Healthcare & Life Sciences' => 'Terveydenhuolto & Life Sciences',
    'industry_Insurance' => 'Vakuutus',
    'industry_Manufacturing' => 'Valmistus',
    'industry_Marketing' => 'Markkinointi',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Apteekit ja lääkeala',
    'industry_Professional Services & Consulting' => 'Vaativat ammattilaispalvelut & konsultointi',
    'industry_Real Estate' => 'Kiinteistönvälitys',
    'industry_Retail & Wholesale' => 'Vähittäis & Tukkukauppa',
    'industry_Sports' => 'Urheilu',
    'industry_Transportation' => 'Kuljetus',
    'industry_Travel & Luxury' => 'Matkailu & Luksus',
    'industry_Other' => 'Muu',
    'industry_Photography' => 'Valokuvaus',

    'view_client_portal' => 'Näytä asiakasportaali',
    'view_portal' => 'Näytä Portaali',
    'vendor_contacts' => 'Kauppiaiden yhteyshenkilöt',
    'all' => 'Kaikki',
    'selected' => 'Selected',
    'category' => 'Kategoria',
    'categories' => 'Kategoriat',
    'new_expense_category' => 'uusi kulu kategoria',
    'edit_category' => 'Muokkaa Kategoriaa',
    'archive_expense_category' => 'Arkistoi Kategoria',
    'expense_categories' => 'kulu kategoriat',
    'list_expense_categories' => 'listaa kulu kategoriat',
    'updated_expense_category' => 'onnistuneesti päivitetty kulukategoria',
    'created_expense_category' => 'onnistuneesti luotu kulukategoria',
    'archived_expense_category' => 'onnistuneesti arkistoitu kulu kategoria',
    'archived_expense_categories' => 'onnistuneesti arkistoitu :count kulu kategoria',
    'restore_expense_category' => 'palauta kulukategoria',
    'restored_expense_category' => 'onnistuneesti palautettu kulukategoria',
    'apply_taxes' => 'Käytä veroja',
    'min_to_max_users' => ':min   :max käyttäjiä',
    'max_users_reached' => 'Käyttäjien maksimimäärä on saavutettu.',
    'buy_now_buttons' => 'Osta nyt napit',
    'landing_page' => 'Landing Page',
    'payment_type' => 'Maksutyyppi',
    'form' => 'Lomake',
    'link' => 'Linkki',
    'fields' => 'Kentät',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Huom:  asiakas ja lasku luodaan, vaikka  maksutapahtumaa ei ole viety loppuun.',
    'buy_now_buttons_disabled' => 'Tämä ominaisuus edellyttää, että tuote on luotu ja  maksutapa on konfiguroitu.',
    'enable_buy_now_buttons_help' => 'Ota käyttöön tuki Osta nyt napeille.',
    'changes_take_effect_immediately' => 'Huom: muutokset tulevat voimaan välittömästi',
    'wepay_account_description' => 'Maksunvälittäjä  ohjelmistolle Lasku Ninja',
    'payment_error_code' => 'Maksusi käsittelyssä tapahtui virhe [:koodi].  Ole hyvä ja yritä myöhemmin uudelleen.',
    'standard_fees_apply' => 'palkkio: 2.9%/1.2% [luotto kortti/Bank Transfer] + $0.30 per successful charge.',
    'limit_import_rows' => 'Data needs  be imported in batches of :count rows tai less',
    'error_title' => 'Jotain meni pieleen...',
    'error_contact_text' => 'Jos tarvitset apua, ole hyvä ja lähetä meille sähköpostia:  :mailaddress',
    'no_undo' => 'Varoitus: Tätä ei voi peruuttaa.',
    'no_contact_selected' => ' Valitse  kontakti',
    'no_client_selected' => 'Valitse asiakas',

    'gateway_config_error' => 'It may help  set uusi passwords tai generate uusi API keys.',
    'payment_type_on_file' => ':tyyppi on tiedosto',
    'invoice_for_client' => 'Lasku :lasku asiakkaalle :asiakas',
    'intent_not_found' => 'Olen pahoillani, mutta en ole varma, mitä haluatte kysyä.',
    'intent_not_supported' => 'Olen pahoillani, mutta en pysty tekemään sitä.',
    'client_not_found' => 'En pystynyt löytämään asiakasta',
    'not_allowed' => 'Pahoittelut, mutta sinulla ei ole tarvittavia oikeuksia',
    'bot_emailed_invoice' => 'Laskusi on lähetetty.',
    'bot_emailed_notify_viewed' => 'Lähetän sinulle sähköpostia, kun se on katsottu.',
    'bot_emailed_notify_paid' => 'Lähetän sinulle sähköpostia kun se on maksettu.',
    'add_product_to_invoice' => 'Lisää 1 :product',
    'not_authorized' => 'Sinulla ei ole oikeutta',
    'bot_get_email' => 'Hi! (wave)<br/>kiitos  trying  Lasku Ninja Bot.<br/>You need  create  free tili  use this bot.<br/>lähetä me tilisi sähköposti osoite  get aloitettu.',
    'bot_get_code' => 'Kiitos! Lähetän sinulle sähköpostin, jossa on turvakoodisi.',
    'bot_welcome' => 'Valmista tuli, käyttäjätilisi on varmennettu.<br/>',
    'email_not_found' => 'En pystynyt löytämään käytössä olevaa sähköpostitiliä :sähköposti',
    'invalid_code' => 'Koodi ei ole oikein',
    'security_code_email_subject' => 'Turvakoodi Lasku Ninja Bot -palveluun',
    'security_code_email_line1' => 'Tämä on sinun turvakoodisi Lasku Ninja Bot -palveluun.',
    'security_code_email_line2' => 'Huom: se vanhenee 10 minuutissa.',
    'bot_help_message' => 'I currently support:<br/>• luo\update\sähköposti  lasku<br/>• listaa tuotteet<br/>For esimerkki:<br/><i>lasku bob  2 tiketit, set  erä päivämäärä  next thursday ja  discount  10 percent</i>',
    'list_products' => 'Listaa tuotteet',

    'include_item_taxes_inline' => 'Sisällytä <b>tuoterivin verot rivin summaan</b>',
    'created_quotes' => 'Onnistuneesti luotu :count tarjous(ta)',
    'limited_gateways' => 'Huom: tuemme yhtä luottokortti-maksutapaa per yritys.',

    'warning' => 'Varoitus',
    'self-update' => 'Päivitä',
    'update_invoiceninja_title' => 'päivitä Lasku Ninja',
    'update_invoiceninja_warning' => 'Ennen kuin aloitat Lasku Ninjan päivityksen luo  varmuuskopio  tietokannasta ja tiedostoista!',
    'update_invoiceninja_available' => 'Uusi versio  Lasku Ninjasta on saatavilla.',
    'update_invoiceninja_unavailable' => 'Ei uutta versiota  Lasku Ninjasta saatavilla.',
    'update_invoiceninja_instructions' => 'Ole hyvä ja asenna  uusi versio <strong>:versio</strong> napsauttamalla <em>Päivitä nyt</em> nappia alla. Sinut ohjatan myöhemmin hallintapaneeliin. ',
    'update_invoiceninja_update_start' => 'päivitä nyt',
    'update_invoiceninja_download_start' => 'Lataa :versio',
    'create_new' => 'luo uusi',

    'toggle_navigation' => 'Toggle Navigation',
    'toggle_history' => 'Toggle History',
    'unassigned' => 'Kohdistamaton',
    'task' => 'Tehtävä',
    'contact_name' => 'Yhteyshenkilön nimi',
    'city_state_postal' => 'Kaupunki/Alue/Postitoimipaikka',
    'custom_field' => 'Mukautettava kenttä',
    'account_fields' => 'Yrityksen kentät',
    'facebook_and_twitter' => 'Facebook ja Twitter',
    'facebook_and_twitter_help' => 'Follow our feeds  help support our projekti',
    'reseller_text' => 'Huom:  white-label lisenssi is intended  personal use,  sähköposti us at :sähköposti jos you\'d like  resell  app.',
    'unnamed_client' => 'Nimeämätön asiakas',

    'day' => 'Päivä',
    'week' => 'Viikko',
    'month' => 'Kuukausi',
    'inactive_logout' => 'Sinut on kirjattu ulos, koska et ole ollut aktiivinen vähään aikaan ',
    'reports' => 'Raportit',
    'total_profit' => 'Tuotot yhteensä',
    'total_expenses' => 'Kulut yhteensä',
    'quote_to' => 'Tarjous:  ',

    // Limits
    'limit' => 'Rajoitus',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Ei rajoitusta',
    'set_limits' => 'Aseta :gateway_type rajoitukset',
    'enable_min' => 'Ota käyttöön min',
    'enable_max' => 'Ota käyttöön max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Tämä lasku ei vastaa ko. maksutavalle asetettuja rajoituksia.',

    'date_range' => 'Päivämääräväli',
    'raw' => 'Raaka',
    'raw_html' => 'Raaka HTML',
    'update' => 'Päivitä',
    'invoice_fields_help' => 'Raahaa ja pudota kenttiä vaihtaaksesi niiden järjestystä ja sijaintia. ',
    'new_category' => 'Uusi kategoria',
    'restore_product' => 'Palauta tuote',
    'blank' => 'Tyhjä',
    'invoice_save_error' => 'Laskusi tallennuksessa tapahtui virhe',
    'enable_recurring' => 'Ota käyttöön toistuva',
    'disable_recurring' => 'Poista käytöstä toistuva',
    'text' => 'Teksti',
    'expense_will_create' => 'kulu  luodaan',
    'expenses_will_create' => 'kulut luodaan',
    'created_expenses' => 'Kulu(ja) onnistuneesti luotu :count',

    'translate_app' => 'Auta parantamaan tämän ohjelman käännöstä :link',
    'expense_category' => 'Kulujen kategoria',

    'go_ninja_pro' => 'Go Ninja Pro!',
    'go_enterprise' => 'Go Enterprise!',
    'upgrade_for_features' => 'Upgrade For lisää Features',
    'pay_annually_discount' => 'Pay annually  10 kuukautta + 2 free!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Mukauta every aspect  sinun lasku!',
    'enterprise_upgrade_feature1' => 'aseta permissions  multiple-users',
    'enterprise_upgrade_feature2' => 'Attach 3rd party files  laskut & kulut',
    'much_more' => 'Much lisää!',
    'all_pro_fetaures' => 'Plus kaikki pro ominaisuudet!',

    'currency_symbol' => 'Symboli',
    'currency_code' => 'Koodi',

    'buy_license' => 'Buy lisenssi',
    'apply_license' => 'Käytä lisenssi',
    'submit' => 'Submit',
    'white_label_license_key' => 'lisenssi Key',
    'invalid_white_label_license' => 'The white label lisenssi ei ole valid',
    'created_by' => 'luotu by :name',
    'modules' => 'Moduulit',
    'financial_year_start' => 'Vuoden ensimmäinen kuukausi',
    'authentication' => 'Authentication',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Signature',
    'show_accept_invoice_terms' => 'Laskun ehdot valintaruutu',
    'show_accept_invoice_terms_help' => 'Vaadi asiakasta  vahvistamaan, että hän hyväksyy laskun ehdot.',
    'show_accept_quote_terms' => 'Tarjouksen ehdot valintaruutu',
    'show_accept_quote_terms_help' => 'Vaadi asiakasta  vahvistamaan, että hän hyväksyy tarjouksen ehdot.',
    'require_invoice_signature' => 'Laskun allekirjoitus',
    'require_invoice_signature_help' => 'Vaadi asiakasta täyttämään allekirjoitus.',
    'require_quote_signature' => 'Tarjouksen allekirjoitus',
    'require_quote_signature_help' => 'Vaadi asiakasta täyttämään allekirjoitus.',
    'i_agree' => 'Hyväksyn ehdot',
    'sign_here' => 'Ole hyvä ja allekirjoita tähän:',
    'authorization' => 'Valtuutus',
    'signed' => 'Allekirjoitettu',

    // BlueVine
    'bluevine_promo' => 'Get flexible business lines  luotto ja lasku factoring using BlueVine.',
    'bluevine_modal_label' => 'Sign up  BlueVine',
    'bluevine_modal_text' => '<h3>Fast funding  sinun business. ei paperwork.</h3>
<ul><li>Flexible business lines  luotto ja lasku factoring.</li></ul>',
    'bluevine_create_account' => 'Luo käyttäjätili',
    'quote_types' => 'Pyydä tarjousta',
    'invoice_factoring' => 'Lasku factoring',
    'line_of_credit' => 'Line  luotto',
    'fico_score' => 'sinun FICO score',
    'business_inception' => 'Business Inception Date',
    'average_bank_balance' => 'Average bank tili balance',
    'annual_revenue' => 'Annual revenue',
    'desired_credit_limit_factoring' => 'Desired lasku factoring limit',
    'desired_credit_limit_loc' => 'Desired line  luottoraja',
    'desired_credit_limit' => 'Desired luottoraja',
    'bluevine_credit_line_type_required' => 'You must choose at least yksi',
    'bluevine_field_required' => 'tämä kenttä vaaditaan',
    'bluevine_unexpected_error' => ' unexpected virhe occurred.',
    'bluevine_no_conditional_offer' => 'Lisää tietoja vaaditaan ennen kuin tarjous voidaan antaa. Napsauta alla \'jatka\'.',
    'bluevine_invoice_factoring' => 'Lasku Factoring',
    'bluevine_conditional_offer' => 'Ehdollinen Tarjous',
    'bluevine_credit_line_amount' => 'luotto Line',
    'bluevine_advance_rate' => 'Advance Rate',
    'bluevine_weekly_discount_rate' => 'viikoittain Discount Rate',
    'bluevine_minimum_fee_rate' => 'Minimum palkkio',
    'bluevine_line_of_credit' => 'Line  luotto',
    'bluevine_interest_rate' => 'korko Rate',
    'bluevine_weekly_draw_rate' => 'viikoittain Draw Rate',
    'bluevine_continue' => 'jatka  BlueVine',
    'bluevine_completed' => 'BlueVine signup valmis',

    'vendor_name' => 'Kauppias',
    'entity_state' => 'Osavaltio',
    'client_created_at' => 'Luotu',
    'postmark_error' => 'Oli ongelma lähetettäessä  sähköposti käyttäen Postmark: :link',
    'project' => 'Projekti',
    'projects' => 'Projektit',
    'new_project' => 'Uusi projekti',
    'edit_project' => 'Muokkaa projektia',
    'archive_project' => 'Arkistoi projekti',
    'list_projects' => 'Listaa projektit',
    'updated_project' => 'Onnistuneesti päivitetty projekti',
    'created_project' => 'Onnistuneesti luotu projekti',
    'archived_project' => 'Onnistuneesti arkistoitu projekti',
    'archived_projects' => 'Onnistuneesti arkistoitu :count projekti(a)',
    'restore_project' => 'Palauta projekti',
    'restored_project' => 'Onnistuneesti palautettu projekti',
    'delete_project' => 'Poista projekti',
    'deleted_project' => 'Projekti poistettu onnistuneesti',
    'deleted_projects' => 'Onnistuneesti poistettu :count projekti(a)',
    'delete_expense_category' => 'Poista category',
    'deleted_expense_category' => 'onnistuneesti poistettu category',
    'delete_product' => 'Poista Tuote',
    'deleted_product' => 'onnistuneesti poistettu tuote',
    'deleted_products' => 'onnistuneesti poistettu :count tuotteet',
    'restored_product' => 'onnistuneesti palautettu tuote',
    'update_credit' => 'päivitä luotto',
    'updated_credit' => 'onnistuneesti päivitetty luotto',
    'edit_credit' => 'muokkaa luotto',
    'realtime_preview' => 'Reaaliaikainen Esikatselu',
    'realtime_preview_help' => 'Päivittää reaaliajassa PDF esikatselun lasku-sivulla kun laskua muokataan.<br/>Poista tämä käytöstä jos haluat nopeuttaa toimintaa.',
    'live_preview_help' => 'näytä live PDF esikatselu lasku-sivulla.',
    'force_pdfjs_help' => 'Replace  built-in PDF viewer in :chrome_link ja :firefox_link.<br/>Enable this jos sinun browser is automatically downloading  PDF.',
    'force_pdfjs' => 'estä lataa',
    'redirect_url' => 'Redirect URL',
    'redirect_url_help' => 'Optionally specify  URL  redirect  after  maksu is entered.',
    'save_draft' => 'Tallenna luonnos',
    'refunded_credit_payment' => 'Refunded luotto maksu',
    'keyboard_shortcuts' => 'Keyboard Shortcuts',
    'toggle_menu' => 'Toggle Menu',
    'new_...' => 'uusi ...',
    'list_...' => 'listaa ...',
    'created_at' => 'Luotu',
    'contact_us' => 'kontakti Us',
    'user_guide' => 'User Guide',
    'promo_message' => 'Upgrade before :expires ja get :amount OFF sinun first year  our Pro tai Enterprise packages.',
    'discount_message' => ':amount off expires :expires',
    'mark_paid' => 'Merkitse maksetuksi',
    'marked_sent_invoice' => 'Lasku on onnistuneesti merkitty lähetetyksi',
    'marked_sent_invoices' => 'Laskut on onnistuneesti merkitty lähetetyiksi',
    'invoice_name' => 'Lasku',
    'product_will_create' => 'Tuote  luodaan',
    'contact_us_response' => 'kiitos you  sinun message! We\'ll try  respond  soon  possible.',
    'last_7_days' => 'Viimeiset 7 päivää',
    'last_30_days' => 'Viimeiset 30 päivää',
    'this_month' => 'tämä kuukausi',
    'last_month' => 'viime kuukausi',
    'current_quarter' => 'nykyinen Quarter',
    'last_quarter' => 'viime Quarter',
    'last_year' => 'viime Year',
    'custom_range' => 'muokattu Range',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Require',
    'license_expiring' => 'Huom: sinun lisenssi will expire in :count days, :link  renew it.',
    'security_confirmation' => 'sinun sähköposti osoite on confirmed.',
    'white_label_expired' => 'sinun white label lisenssi on expired,  consider renewing it  help support our projekti.',
    'renew_license' => 'Renew lisenssi',
    'iphone_app_message' => 'Consider downloading our :link',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Logged In',
    'switch_to_primary' => 'Switch  sinun primary yritys (:name)  manage sinun plan.',
    'inclusive' => 'Inclusive',
    'exclusive' => 'Exclusive',
    'postal_city_state' => 'Postal/kaupunki/State',
    'phantomjs_help' => 'In certain cases  app uses :link_phantom  generate  PDF, asenna :link_docs  generate it locally.',
    'phantomjs_local' => 'Using paikallinen PhantomJS',
    'client_number' => 'asiakas numero',
    'client_number_help' => 'määritä  etuliite tai use  custom pattern  dynamically set  asiakas numero.',
    'next_client_number' => 'The next asiakas numero is :numero.',
    'generated_numbers' => 'Generated Numbers',
    'notes_reminder1' => 'Ensimmäinen muistutus',
    'notes_reminder2' => 'Toinen muistutus',
    'notes_reminder3' => 'Kolmas muistutus',
    'notes_reminder4' => 'muistutus',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'Tarjouksen vero',
    'tax_invoice' => 'vero Lasku',
    'emailed_invoices' => 'onnistuneesti emailed laskut',
    'emailed_quotes' => 'Lähetetty onnistuneesti tarjoukset sähköpostitse',
    'website_url' => 'Website URL',
    'domain' => 'Domain',
    'domain_help' => 'Käytetään asiakasportaalissa ja lähetettäessä sähköposteja.',
    'domain_help_website' => 'Käytetään lähetettäessä sähköposteja.',
    'import_invoices' => 'Import laskut',
    'new_report' => 'uusi raportti',
    'edit_report' => 'muokkaa raportti',
    'columns' => 'Columns',
    'filters' => 'Filters',
    'sort_by' => 'Järjestä',
    'draft' => 'Luonnos',
    'unpaid' => 'Maksamaton',
    'aging' => 'Aging',
    'age' => 'Age',
    'days' => 'Päivää',
    'age_group_0' => '0 - 30 päivää',
    'age_group_30' => '30 - 60 päivää',
    'age_group_60' => '60 - 90 päivää',
    'age_group_90' => '90 - 120 päivää',
    'age_group_120' => '120+ päivää',
    'invoice_details' => 'Laskun tiedot',
    'qty' => 'Määrä',
    'profit_and_loss' => 'Profit ja Loss',
    'revenue' => 'Revenue',
    'profit' => 'Profit',
    'group_when_sorted' => 'ryhmä Sort',
    'group_dates_by' => 'ryhmä Dates By',
    'year' => 'Vuosi',
    'view_statement' => 'Näytä Tiliote',
    'statement' => 'tiliote',
    'statement_date' => 'tiliote Date',
    'mark_active' => 'Merkitse aktiiviseksi',
    'send_automatically' => 'lähetä automaattisesti',
    'initial_email' => 'Initial Email',
    'invoice_not_emailed' => 'tämä lasku ei ole emailed.',
    'quote_not_emailed' => 'Tätä tarjousta ei ole lähetetty sähköpostitse.',
    'sent_by' => 'Sent by :käyttäjä',
    'recipients' => 'Recipients',
    'save_as_default' => 'Save  oletus',
    'start_of_week_help' => 'Käytetään <b>päivämäärä</b> valinnoissa',
    'financial_year_start_help' => 'Käytetään <b>päivämääräväli</b> valinnoissa',
    'reports_help' => 'Shift + Click  sort by multiple columns, Ctrl + Click  clear  grouping.',
    'this_year' => 'tämä Year',

    // Updated login screen
    'ninja_tagline' => 'luo. lähetä. Get Paid.',
    'login_or_existing' => 'Or login with  connected tili.',
    'sign_up_now' => 'Sign Up Now',
    'not_a_member_yet' => 'Not  member yet?',
    'login_create_an_account' => 'luo  Account!',

    // New Client Portal styling
    'invoice_from' => 'laskut From:',
    'email_alias_message' => 'We require each yritys  have  unique sähköposti osoite.<br/>Consider using  alias. ie, sähköposti+label@esimerkki.com',
    'full_name' => 'Full nimi',
    'month_year' => 'MONTH/YEAR',
    'valid_thru' => 'Valid\nthru',

    'product_fields' => 'Tuote kentät',
    'custom_product_fields_help' => 'Lisää  kenttä luotaessa tuote tai lasku ja näytä otsikko ja arvo  PDF:ssä.',
    'freq_two_months' => 'Kaksi kuukautta',
    'freq_yearly' => 'Vuosittain',
    'profile' => 'Profiili',
    'payment_type_help' => 'Asettaa oletuksena <b>manuaalisen maksutavan</b>.',
    'industry_Construction' => 'Construction',
    'your_statement' => 'sinun tiliote',
    'statement_issued_to' => 'tiliote issued  ',
    'statement_to' => 'tiliote  ',
    'customize_options' => 'Mukauta valintoja',
    'created_payment_term' => 'onnistuneesti luotu maksu ehto',
    'updated_payment_term' => 'onnistuneesti päivitetty maksu ehto',
    'archived_payment_term' => 'onnistuneesti arkistoitu maksu ehto',
    'resend_invite' => 'Resend Invitation',
    'credit_created_by' => 'luotto luotu by maksu :transaction_reference',
    'created_payment_and_credit' => 'onnistuneesti luotu maksu ja luotto',
    'created_payment_and_credit_emailed_client' => 'onnistuneesti luotu maksu ja luotto, ja emailed asiakas',
    'create_project' => 'Luo projekti',
    'create_vendor' => 'Luo kauppias',
    'create_expense_category' => 'Luo kategoria',
    'pro_plan_reports' => ':link  enable reports by joining  Pro Plan',
    'mark_ready' => 'Merkitse valmiiksi',

    'limits' => 'Limits',
    'fees' => 'palkkiot',
    'fee' => 'palkkio',
    'set_limits_fees' => 'aseta :gateway_type Limits/palkkiot',
    'fees_tax_help' => 'Enable line item verot  set  palkkio tax rates.',
    'fees_sample' => 'The palkkio  a :amount lasku would be :total.',
    'discount_sample' => 'The discount  a :amount lasku would be :total.',
    'no_fees' => 'ei palkkiot',
    'gateway_fees_disclaimer' => 'Warning: not kaikki states/maksu gateways allow adding palkkioita,  review paikallinen laws/terms  service.',
    'percent' => 'Prosentti',
    'location' => 'Location',
    'line_item' => 'Line Item',
    'surcharge' => 'Surcharge',
    'location_first_surcharge' => 'Enabled - ensimmäinen surcharge',
    'location_second_surcharge' => 'Enabled - toinen surcharge',
    'location_line_item' => 'Enabled - Line item',
    'online_payment_surcharge' => 'Online maksu Surcharge',
    'gateway_fees' => 'Gateway palkkiot',
    'fees_disabled' => 'palkkiot on pois käytöstä',
    'gateway_fees_help' => 'automaattisesti lisää  online maksu surcharge/discount.',
    'gateway' => 'Maksunvälittäjä',
    'gateway_fee_change_warning' => 'Maksamattomat laskut, joihin sisältyy viivästysmaksuja, täytyy päivittää manuaalisesti.',
    'fees_surcharge_help' => 'Mukauta surcharge :link.',
    'label_and_taxes' => 'label ja verot',
    'billable' => 'Billable',
    'logo_warning_too_large' => 'The kuva tiedosto is too iso.',
    'logo_warning_fileinfo' => 'Warning: To support gifs  fileinfo PHP extension needs  be enabled.',
    'logo_warning_invalid' => 'Oli  ongelma reading  kuva tiedosto,  yritä  eri muoto.',

    'error_refresh_page' => ' virhe occurred,  refresh  page ja try again.',
    'data' => 'Data',
    'imported_settings' => 'onnistuneesti imported asetus',
    'reset_counter' => 'Reset Counter',
    'next_reset' => 'Next Reset',
    'reset_counter_help' => 'Nollaa automaattisesti lasku- ja tarjouslaskurit. ',
    'auto_bill_failed' => 'Automaattinen laskutus  laskulle :invoice_number epäonnistui',
    'online_payment_discount' => 'Online maksu Discount',
    'created_new_company' => 'onnistuneesti luotu uusi yritys',
    'fees_disabled_for_gateway' => 'palkkiot on pois käytöstä  this gateway.',
    'logout_and_delete' => 'Log Out/Poista Account',
    'tax_rate_type_help' => 'Inclusive tax rates adjust  line item cost when selected.<br/>Only exclusive tax rates can be used as  oletus.',
    'invoice_footer_help' => 'Käytä $pageNumber ja $pageCount  näyttääksesi sivun tiedot.',
    'credit_note' => 'luotto Huom',
    'credit_issued_to' => 'luotto issued  ',
    'credit_to' => 'luotto  ',
    'your_credit' => 'sinun luotto',
    'credit_number' => 'luotto numero',
    'create_credit_note' => 'luo luotto Huom',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Virhe: The gateways table on incorrect ids.',
    'purge_data' => 'Purge Data',
    'delete_data' => 'Poista Data',
    'purge_data_help' => 'pysyvästi poista kaikki data but keep  tili ja asetus.',
    'cancel_account_help' => 'pysyvästi poista  tili along  kaikki data ja asetus.',
    'purge_successful' => 'onnistuneesti purged yritys data',
    'forbidden' => 'Forbidden',
    'purge_data_message' => 'Warning: tämä will pysyvästi erase sinun data, there is no undo.',
    'contact_phone' => 'kontakti puhelin',
    'contact_email' => 'kontakti Email',
    'reply_to_email' => 'Reply-To Email',
    'reply_to_email_help' => 'määritä  vastaus- osoite  asiakas sähköpostit.',
    'bcc_email_help' => 'Privately include this osoite  asiakas sähköpostit.',
    'import_complete' => 'sinun tuonti on onnistuneesti valmis.',
    'confirm_account_to_import' => ' vahvista tilisi  tuonti data.',
    'import_started' => 'sinun tuonti on aloitettu, we\'ll send you  sähköposti once it valmistuu.',
    'listening' => 'Listening...',
    'microphone_help' => 'Say "uusi invoice for [client]" tai "show me [client]\'s arkistoitu payments"',
    'voice_commands' => 'Voice Commands',
    'sample_commands' => 'Sample commands',
    'voice_commands_feedback' => 'We\'re actively working  improve this feature, jos there\'s  command you\'d like us  support  sähköposti us at :sähköposti.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'onnistuneesti arkistoitu :count tuotteet',
    'recommend_on' => 'We recommend <b>enabling</b> this asetus.',
    'recommend_off' => 'We recommend <b>disabling</b> this asetus.',
    'notes_auto_billed' => 'automaattinen-billed',
    'surcharge_label' => 'Surcharge Label',
    'contact_fields' => 'kontakti kentät',
    'custom_contact_fields_help' => 'Lisää  kenttä luotaessa yhteyshenkilö ja valinnaisesti näytä otsikko ja arvo  PDF:ssä.',
    'datatable_info' => 'Showing :start   :end of :total entries',
    'credit_total' => 'luotto yhteensä',
    'mark_billable' => 'Merkitse laskutettavaksi',
    'billed' => 'Billed',
    'company_variables' => 'yritys muuttujat',
    'client_variables' => 'asiakas muuttujat',
    'invoice_variables' => 'Lasku muuttujat',
    'navigation_variables' => 'Navigation muuttujat',
    'custom_variables' => 'muokattu muuttujat',
    'invalid_file' => 'epäkelpo tiedosto tyyppi',
    'add_documents_to_invoice' => 'Lisää asiakirjoja laskuun',
    'mark_expense_paid' => 'Merkitse maksetuksi',
    'white_label_license_error' => 'Failed  validate  lisenssi, tarkista storage/logs/laravel-virhe.log  more tiedot.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation koodi',
    'oauth_taken' => 'The tili is already registered',
    'emailed_payment' => 'onnistuneesti emailed maksu',
    'email_payment' => 'Email maksu',
    'invoiceplane_import' => 'käytä :link  migrate sinun data from InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: tämä :link may be  duplicate',
    'expense_link' => 'kulu',
    'resume_task' => 'Jatka tehtävää',
    'resumed_task' => 'Onnistuneesti jatkettu tehtävää',
    'quote_design' => 'Tarjouksen muotoilu',
    'default_design' => 'Standard malli',
    'custom_design1' => 'muokattu malli 1',
    'custom_design2' => 'muokattu malli 2',
    'custom_design3' => 'muokattu malli 3',
    'empty' => 'Empty',
    'load_design' => 'Load malli',
    'accepted_card_logos' => 'Accepted kortti Logos',
    'phantomjs_local_and_cloud' => 'Using paikallinen PhantomJS, falling back  phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Track payments using :link',
    'start_date_required' => 'The start päivämäärä vaaditaan',
    'application_settings' => 'Application asetukset',
    'database_connection' => 'tietokanta Connection',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'tietokanta',
    'test_connection' => 'Test yhteys',
    'from_name' => 'From nimi',
    'from_address' => 'From Address',
    'port' => 'portti',
    'encryption' => 'Encryption',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'lähetä test sähköposti',
    'select_label' => 'Select Label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Päivitä maksu tiedot',
    'updated_payment_details' => 'Onnistuneesti päivitetty maksun tiedot',
    'update_credit_card' => 'päivitä luotto kortti',
    'recurring_expenses' => 'toistuva kulut',
    'recurring_expense' => 'toistuva kulu',
    'new_recurring_expense' => 'uusi toistuva kulu',
    'edit_recurring_expense' => 'muokkaa toistuva kulu',
    'archive_recurring_expense' => 'Arkistoi toistuva kulu',
    'list_recurring_expense' => 'listaa toistuva kulut',
    'updated_recurring_expense' => 'onnistuneesti päivitetty toistuva kulu',
    'created_recurring_expense' => 'onnistuneesti luotu toistuva kulu',
    'archived_recurring_expense' => 'onnistuneesti arkistoitu toistuva kulu',
    'restore_recurring_expense' => 'palauta toistuva kulu',
    'restored_recurring_expense' => 'onnistuneesti palautettu toistuva kulu',
    'delete_recurring_expense' => 'Poista toistuva kulu',
    'deleted_recurring_expense' => 'Projekti poistettu onnistuneesti',
    'view_recurring_expense' => 'View toistuva kulu',
    'taxes_and_fees' => 'verot ja palkkioita',
    'import_failed' => 'Import Failed',
    'recurring_prefix' => 'toistuva etuliite',
    'options' => 'Valinnat',
    'credit_number_help' => 'määritä  etuliite tai use  custom pattern  dynamically set  luotto numero  negative laskut.',
    'next_credit_number' => 'The next luotto numero is :numero.',
    'padding_help' => 'The numero  zero\'s  pad  numero.',
    'import_warning_invalid_date' => 'Warning: The päivämäärä format appears  be invalid.',
    'product_notes' => 'Tuotteen huomiot',
    'app_version' => 'App versio',
    'ofx_version' => 'OFX versio',
    'gateway_help_23' => ':link  get sinun Stripe API keys.',
    'error_app_key_set_to_default' => 'Virhe: APP_KEY is set    oletus arvo,  update it varmuuskopio sinun database ja then run <koodi>php artisan ninja:update-avain</koodi>',
    'charge_late_fee' => 'Charge Late palkkio',
    'late_fee_amount' => 'Late palkkio määrä',
    'late_fee_percent' => 'Late palkkio Percent',
    'late_fee_added' => 'Late palkkio added on :date',
    'download_invoice' => 'lataa Lasku',
    'download_quote' => 'Lataa tarjous',
    'invoices_are_attached' => 'sinun lasku PDFs on attached.',
    'downloaded_invoice' => ' sähköposti  lähettää with  lasku PDF',
    'downloaded_quote' => 'Sähköposti lähetään ja sen liitteenä tarjous PDF',
    'downloaded_invoices' => ' sähköposti  lähettää with  lasku PDFs',
    'downloaded_quotes' => 'Sähköposti lähetään ja sen liitteenä tarjous PDF:t',
    'clone_expense' => 'kloonaa kulu',
    'default_documents' => 'oletus Documents',
    'send_email_to_client' => 'lähetä sähköposti    asiakas',
    'refund_subject' => 'Refund Processed',
    'refund_body' => 'You have been processed  hyvitys of :amount  lasku :invoice_number.',

    'currency_us_dollar' => 'US dollari',
    'currency_british_pound' => 'British Pound',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian dollari',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian dollari',
    'currency_singapore_dollar' => 'Singapore dollari',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'uusi Zealand dollari',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong dollari',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad ja Tobago dollari',
    'currency_east_caribbean_dollar' => 'East Caribbean dollari',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian uusi Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian dollari',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan uusi dollari',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua uusi Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian dollari',
    'currency_brunei_dollar' => 'Brunei dollari',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese dollari',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican dollari',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian dollari',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia ja Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using  app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing  review',

    'use_english_version' => 'Make sure  use  English versio of  files.<br/>We use  column headers  match  fields.',
    'tax1' => 'ensimmäinen vero',
    'tax2' => 'toinen vero',
    'fee_help' => 'Gateway palkkioita on  costs charged  access    financial networks that handle  processing  online payments.',
    'format_export' => 'Exporting format',
    'custom1' => 'ensimmäinen muokattu',
    'custom2' => 'toinen muokattu',
    'contact_first_name' => 'kontakti ensimmäinen nimi',
    'contact_last_name' => 'kontakti viime nimi',
    'contact_custom1' => 'kontakti ensimmäinen muokattu',
    'contact_custom2' => 'kontakti toinen muokattu',
    'currency' => 'Valuutta',
    'ofx_help' => 'To troubleshoot tarkista  comments on :ofxhome_link ja test with :ofxget_link.',
    'comments' => 'comments',

    'item_product' => 'Tuote nimike',
    'item_notes' => 'Item Notes',
    'item_cost' => 'Item hinta',
    'item_quantity' => 'Item Quantity',
    'item_tax_rate' => 'Item vero Rate',
    'item_tax_name' => 'Item veronimi',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Poista yritys',
    'delete_company_help' => 'pysyvästi poista  yritys along  kaikki data ja asetus.',
    'delete_company_message' => 'Warning: tämä will pysyvästi poista sinun yritys, there is no undo.',

    'applied_discount' => 'The kuponki on applied,  plan hinta on reduced by :discount%.',
    'applied_free_year' => 'The kuponki on applied, tilisi on upgraded  pro  yksi year.',

    'contact_us_help' => 'If you\'re reporting  virhe  include any relevant logs from storage/logs/laravel-virhe.log',
    'include_errors' => 'Include Errors',
    'include_errors_help' => 'Include :link from storage/logs/laravel-virhe.log',
    'recent_errors' => 'recent errors',
    'customer' => 'asiakas',
    'customers' => 'asiakkaat',
    'created_customer' => 'onnistuneesti luotu asiakas',
    'created_customers' => 'onnistuneesti luotu :count asiakasta',

    'purge_details' => 'The data in sinun yritys (:tili) on onnistuneesti purged.',
    'deleted_company' => 'onnistuneesti poistettu yritys',
    'deleted_account' => 'onnistuneesti peruutettu tili',
    'deleted_company_details' => 'sinun yritys (:account) on onnistuneesti poistettu.',
    'deleted_account_details' => 'sinun tili (:account) on onnistuneesti poistettu.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA-maksu',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Accept EU bank transfers',
    'stripe_alipay_help' => 'These gateways also need  be activated in :link.',
    'calendar' => 'Calendar',
    'pro_plan_calendar' => ':link  enable  kalenteri by joining  Pro Plan',

    'what_are_you_working_on' => 'What on you working on?',
    'time_tracker' => 'Työajan seuranta',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'ei Description',
    'time_tracker_login' => 'Työajan seurannan kirjautuminen',
    'save_or_discard' => 'Save tai discard sinun muutokset',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tehtävät eivät ole käytössä.',
    'started_task' => 'Onnistuneesti aloitettu tehtävä',
    'create_client' => 'luo asiakas',

    'download_desktop_app' => 'lataa  desktop app',
    'download_iphone_app' => 'lataa  iPhone app',
    'download_android_app' => 'lataa  Android app',
    'time_tracker_mobile_help' => 'Kaksoisnapauta tehtävää valitaksesi sen',
    'stopped' => 'Stopped',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
    'sort_field' => 'Järjestä',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Huom: Online-maksujen vastaanottaminen vaatii maksujen käsittelyjärjestelmän (maksutavan),  :link  lisätäksesi sellaisen.',
    'task_rate' => 'Tehtävän luokitus',
    'task_rate_help' => 'Aseta oletus luokitus laskutetuille tehtäville.',
    'past_due' => 'Past Due',
    'document' => 'Document',
    'invoice_or_expense' => 'Lasku/kulu',
    'invoice_pdfs' => 'Lasku PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing sinun IBAN ja confirming this maksu, you on authorizing :yritys ja Stripe, our maksu service provider,  send ohjeet  sinun bank  debit tilisi ja sinun bank  debit tilisi in accordance  those ohjeet. You on entitled    hyvitys from sinun bank under  terms ja conditions  sinun agreement  sinun bank. A hyvitys must be claimed within 8 viikkoa starting from  päivämäärä on which tilisi was debited.',
    'recover_license' => 'Recover lisenssi',
    'purchase' => 'Purchase',
    'recover' => 'Recover',
    'apply' => 'Käytä',
    'recover_white_label_header' => 'Recover White Label lisenssi',
    'apply_white_label_header' => 'Käytä White Label -lisenssiä',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Return  Lasku',
    'gateway_help_13' => 'To use ITN leave  PDT Key kenttä blank.',
    'partial_due_date' => 'Partial eräpäivä',
    'task_fields' => 'Tehtävän kentät',
    'product_fields_help' => 'Drag ja drop fields  change their order',
    'custom_value1' => 'muokattu Value',
    'custom_value2' => 'Mukautettu arvo',
    'enable_two_factor' => 'Kaksivaiheinen tunnistautuminen',
    'enable_two_factor_help' => 'Käytä puhelintasi vahvistaaksesi identiteettisi, kun olet kirjautumassa sisään',
    'two_factor_setup' => 'Kaksivaiheinen asennus',
    'two_factor_setup_help' => 'Scan  bar koodi  a :link compatible app.',
    'one_time_password' => 'Kertakäyttöinen salasana',
    'set_phone_for_two_factor' => 'aseta sinun matkapuhelin numero as  varmuuskopio  enable.',
    'enabled_two_factor' => 'Kaksivaiheinen tunnistautuminen otettu onnistuneesti käyttöön ',
    'add_product' => 'Lisää tuote',
    'email_will_be_sent_on' => 'Huom:  sähköposti  lähettää on :päivämäärä.',
    'invoice_product' => 'Lasku Tuote',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Virhe: paikallinen storage ei ole saatavilla.',
    'your_password_reset_link' => 'sinun salasanan palautus linkki',
    'subdomain_taken' => 'The alidomain is already in use',
    'client_login' => 'Asiakasportaali',
    'converted_amount' => 'Converted määrä',
    'default' => 'oletus',
    'shipping_address' => 'Toimitusosoite',
    'bllling_address' => 'Laskutusosoite',
    'billing_address1' => 'Laskutus: Katu',
    'billing_address2' => 'Laskutus: Asunto/huoneisto',
    'billing_city' => 'Laskutus: Kaupunki',
    'billing_state' => 'Laskutus: Maakunta',
    'billing_postal_code' => 'Laskutus: Postinumero',
    'billing_country' => 'Laskutus: Maa',
    'shipping_address1' => 'Toimitus: Katu',
    'shipping_address2' => 'Toimitus: Asunto/huoneisto',
    'shipping_city' => 'Toimitus: Kaupunki',
    'shipping_state' => 'Toimitus: Maakunta',
    'shipping_postal_code' => 'Toimitus: Postinumero',
    'shipping_country' => 'Toimitus: Maa',
    'classify' => 'Luokittelu',
    'show_shipping_address_help' => 'Vaadi asiakasta täyttämään toimitusosoite',
    'ship_to_billing_address' => 'Toimitetaan  laskutusosoitteeseen',
    'delivery_note' => 'Delivery Huom',
    'show_tasks_in_portal' => 'Näytä tehtävät asiakasportaalssa',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled raportti',
    'scheduled_report_help' => 'Email the :raportti raportti as :format   :sähköposti',
    'created_scheduled_report' => 'onnistuneesti scheduled raportti',
    'deleted_scheduled_report' => 'onnistuneesti peruutettu scheduled raportti',
    'scheduled_report_attached' => 'sinun scheduled :tyyppi raportti is attached.',
    'scheduled_report_error' => 'Failed  create schedule raportti',
    'invalid_one_time_password' => 'Kelpaamaton kertakäyttöinen salasana',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay ja Pay  Google',
    'requires_subdomain' => 'tämä maksutapa requires that a :link.',
    'subdomain_is_set' => 'alidomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification tiedosto is needed  accept payments.',
    'apple_pay_domain' => 'käytä <koodi>:domain</koodi> as  domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay ei ole supported by sinun browser',
    'optional_payment_methods' => 'Optional maksu Methods',
    'add_subscription' => 'Lisää tilaus',
    'target_url' => 'Target',
    'target_url_help' => 'When  selected event occurs  app will post  entity    target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'luotu asiakas',
    'subscription_event_2' => 'luotu Lasku',
    'subscription_event_3' => 'Tarjous luotu',
    'subscription_event_4' => 'luotu maksu',
    'subscription_event_5' => 'Luotu kauppias',
    'subscription_event_6' => 'Tarjous päivitetty',
    'subscription_event_7' => 'Tarjous poistettu',
    'subscription_event_8' => 'päivitetty Lasku',
    'subscription_event_9' => 'poistettu Lasku',
    'subscription_event_10' => 'päivitetty asiakas',
    'subscription_event_11' => 'poistettu asiakas',
    'subscription_event_12' => 'poistettu maksu',
    'subscription_event_13' => 'Päivitetty kauppias',
    'subscription_event_14' => 'Poistettu kauppias',
    'subscription_event_15' => 'luotu kulu',
    'subscription_event_16' => 'päivitetty kulu',
    'subscription_event_17' => 'poistettu kulu',
    'subscription_event_18' => 'Luotu tehtävä',
    'subscription_event_19' => 'Päivitetty tehtävä',
    'subscription_event_20' => 'Poistettu tehtävä',
    'subscription_event_21' => 'Tarjous hyväksytty',
    'subscriptions' => 'Subscriptions',
    'updated_subscription' => 'onnistuneesti päivitetty tilaus',
    'created_subscription' => 'onnistuneesti luotu tilaus',
    'edit_subscription' => 'muokkaa tilaus',
    'archive_subscription' => 'Arkistoi tilaus',
    'archived_subscription' => 'onnistuneesti arkistoitu tilaus',
    'project_error_multiple_clients' => 'Projektit eivät voi kuulua eri asiakkaille',
    'invoice_project' => 'Lasku projekti',
    'module_recurring_invoice' => 'Toistuvat laskut',
    'module_credit' => 'Luotot',
    'module_quote' => 'Tarjoukset & Ehdotukset',
    'module_task' => 'Tehtävät & Projektit',
    'module_expense' => 'Kulut & Kauppiaat',
    'module_ticket' => 'Tiketit',
    'reminders' => 'muistutukset',
    'send_client_reminders' => 'lähetä sähköposti reminders',
    'can_view_tasks' => 'Tehtävät ovat näkyvissä portaalissa',
    'is_not_sent_reminders' => 'muistutukset on not lähettää',
    'promotion_footer' => 'sinun promotion will expire soon, :link  upgrade nyt.',
    'unable_to_delete_primary' => 'Huom:  poista this yritys first poista kaikki linked companies.',
    'please_register' => ' rekisteröi tilisi',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command  update sinun cipher.',
    'edit_times' => 'Muokkaa aikoja',
    'inclusive_taxes_help' => 'Include <b>verot in  cost</b>',
    'inclusive_taxes_notice' => 'tämä asetus ei voi vaihdettu once  lasku on luotu.',
    'inclusive_taxes_warning' => 'Warning: existing laskut will need  be resaved',
    'copy_shipping' => 'Kopioi toimitus',
    'copy_billing' => 'Kopioi laskutus',
    'quote_has_expired' => 'Tarjous on vanhentunut, ole hyvä ja ole yhteydessä myyntihenkilöömme.',
    'empty_table_footer' => 'Showing 0  0  0 entries',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Trust  30 days',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready  do',
    'in_progress' => 'In progress',
    'add_status' => 'Lisää tila',
    'archive_status' => 'Arkistoi tila',
    'new_status' => 'uusi tila',
    'convert_products' => 'Convert tuotteet',
    'convert_products_help' => 'Muunna automaattisesti tuotehinnat asiakkaan valuuttaan',
    'improve_client_portal_link' => 'aseta  alidomain  shorten  asiakas portal link.',
    'budgeted_hours' => 'Budjetoidut työtunnit',
    'progress' => 'Progress',
    'view_project' => 'Näytä Projekti',
    'summary' => 'Summary',
    'endless_reminder' => 'Endless muistutus',
    'signature_on_invoice_help' => 'Lisää  seuraava koodi  näyttääksesi asiakkaasi allekirjoituksen PDF:ssä.',
    'signature_on_pdf' => 'näytä on PDF',
    'signature_on_pdf_help' => 'Näytä asiakkaan allekirjoitus lasku-/tarjous-PDF:ssä.',
    'expired_white_label' => 'The white label lisenssi on expired',
    'return_to_login' => 'Palaa kirjautumisnäyttöön',
    'convert_products_tip' => 'Huom: lisää :link nimellä ":name"  nähdäksesi vaihtokurssin.',
    'amount_greater_than_balance' => 'The amount is greater than  lasku balance,  luotto  luotu with  remaining amount.',
    'custom_fields_tip' => 'käytä <koodi>Label|Option1,Option2</koodi>  show  valitse box.',
    'client_information' => 'asiakas Information',
    'updated_client_details' => 'Onnistuneesti päivitetty asiakkaan tiedot',
    'auto' => 'automaattinen',
    'tax_amount' => 'vero määrä',
    'tax_paid' => 'vero Paid',
    'none' => 'None',
    'proposal_message_button' => 'To view sinun proposal for :amount, click  nappi alla.',
    'proposal' => 'ehdotus',
    'proposals' => 'Ehdotukset',
    'list_proposals' => 'Listaa ehdotukset',
    'new_proposal' => 'uusi ehdotus',
    'edit_proposal' => 'muokkaa ehdotus',
    'archive_proposal' => 'Arkistoi ehdotus',
    'delete_proposal' => 'Poista ehdotus',
    'created_proposal' => 'onnistuneesti luotu proposal',
    'updated_proposal' => 'onnistuneesti päivitetty proposal',
    'archived_proposal' => 'Ehdotus on arkistoitu onnistuneesti',
    'deleted_proposal' => 'Ehdotus on arkistoitu onnistuneesti',
    'archived_proposals' => 'Onnistuneesti arkistoitu :count ehdotusta',
    'deleted_proposals' => 'onnistuneesti arkistoitu :count proposals',
    'restored_proposal' => 'onnistuneesti palautettu proposal',
    'restore_proposal' => 'Palauta ehdotus',
    'snippet' => 'Pätkä',
    'snippets' => 'Pätkät',
    'proposal_snippet' => 'Pätkä',
    'proposal_snippets' => 'Pätkät',
    'new_proposal_snippet' => 'uusi Snippet',
    'edit_proposal_snippet' => 'muokkaa Snippet',
    'archive_proposal_snippet' => 'Arkistoi Snippet',
    'delete_proposal_snippet' => 'Poista Snippet',
    'created_proposal_snippet' => 'onnistuneesti luotu snippet',
    'updated_proposal_snippet' => 'onnistuneesti päivitetty snippet',
    'archived_proposal_snippet' => 'onnistuneesti arkistoitu snippet',
    'deleted_proposal_snippet' => 'onnistuneesti arkistoitu snippet',
    'archived_proposal_snippets' => 'onnistuneesti arkistoitu :count snippets',
    'deleted_proposal_snippets' => 'onnistuneesti arkistoitu :count snippets',
    'restored_proposal_snippet' => 'onnistuneesti palautettu snippet',
    'restore_proposal_snippet' => 'palauta Snippet',
    'template' => 'Malli',
    'templates' => 'Mallit',
    'proposal_template' => 'Malli',
    'proposal_templates' => 'Mallit',
    'new_proposal_template' => 'uusi pohja',
    'edit_proposal_template' => 'muokkaa pohja',
    'archive_proposal_template' => 'Arkistoi malli',
    'delete_proposal_template' => 'Poista pohja',
    'created_proposal_template' => 'onnistuneesti luotu template',
    'updated_proposal_template' => 'onnistuneesti päivitetty template',
    'archived_proposal_template' => 'onnistuneesti arkistoitu template',
    'deleted_proposal_template' => 'onnistuneesti arkistoitu template',
    'archived_proposal_templates' => 'onnistuneesti arkistoitu :count templates',
    'deleted_proposal_templates' => 'onnistuneesti arkistoitu :count templates',
    'restored_proposal_template' => 'onnistuneesti palautettu template',
    'restore_proposal_template' => 'palauta pohja',
    'proposal_category' => 'kategoria',
    'proposal_categories' => 'kategoriat',
    'new_proposal_category' => 'uusi kategoria',
    'edit_proposal_category' => 'muokkaa kategoria',
    'archive_proposal_category' => 'Arkistoi kategoria',
    'delete_proposal_category' => 'Poista kategoria',
    'created_proposal_category' => 'onnistuneesti luotu category',
    'updated_proposal_category' => 'onnistuneesti päivitetty category',
    'archived_proposal_category' => 'onnistuneesti arkistoitu kategoria',
    'deleted_proposal_category' => 'onnistuneesti arkistoitu kategoria',
    'archived_proposal_categories' => 'onnistuneesti arkistoitu :count categories',
    'deleted_proposal_categories' => 'onnistuneesti arkistoitu :count categories',
    'restored_proposal_category' => 'onnistuneesti palautettu category',
    'restore_proposal_category' => 'palauta kategoria',
    'delete_status' => 'Poista tila',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'The requested proposal ei ole saatavilla',
    'create_proposal_category' => 'luo category',
    'clone_proposal_template' => 'kloonaa pohja',
    'proposal_email' => 'Ehdotus sähköposti',
    'proposal_subject' => 'uusi proposal :numero from :tili',
    'proposal_message' => 'To view sinun proposal for :amount, click  link alla.',
    'emailed_proposal' => 'onnistuneesti emailed proposal',
    'load_template' => 'Load pohja',
    'no_assets' => 'ei images, drag  upload',
    'add_image' => 'Lisää kuva',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade    enterprise plan  upload images',
    'delete_image' => 'Poista Image',
    'delete_image_help' => 'Warning: deleting  kuva will remove it from kaikki proposals.',
    'amount_variable_help' => 'Huom:  lasku $amount kenttä will use  partial/deposit kenttä jos set otherwise it will use  lasku balance.',
    'taxes_are_included_help' => 'Huom: Inclusive verot have been enabled.',
    'taxes_are_not_included_help' => 'Huom: Inclusive verot on not enabled.',
    'change_requires_purge' => 'Changing this asetus requires :link  tili data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The hyvitys  recorded in  app but will NOT be processed by  maksu gateway.',
    'email_address_changed' => 'sähköpostiosoite on vaihdettu',
    'email_address_changed_message' => 'The sähköposti osoite  tilisi on vaihdettu from :old_email   :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting  ZIP requires  GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'Ei löydetty viestejä',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The sähköposti osoite on reactivated',
    'emails' => 'sähköpostit',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'yhteensä Sent',
    'total_opened' => 'yhteensä Opened',
    'total_bounced' => 'yhteensä Bounced',
    'total_spam' => 'yhteensä Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email asiakkaat',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'ryhmä',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve vastaanottanut  uusi maksu!',
    'slack_webhook_help' => 'Receive maksu notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'onnistuneesti accepted  latest terms  service',
    'invalid_url' => 'epäkelpo URL',
    'workflow_settings' => 'Workflow asetukset',
    'auto_email_invoice' => 'automaattinen Email',
    'auto_email_invoice_help' => 'automaattisesti sähköposti toistuva laskut when they on luotu.',
    'auto_archive_invoice' => 'automaattinen Arkistoi',
    'auto_archive_invoice_help' => 'automaattisesti archive laskut when they on paid.',
    'auto_archive_quote' => 'automaattinen Arkistoi',
    'auto_archive_quote_help' => 'Arkistoi tarjoukset automaattisesti kun ne on muunnettu laskuiksi.',
    'require_approve_quote' => 'Vaadi tarjouksen hyväksymistä',
    'require_approve_quote_help' => 'Vaadi, että asiakkaat  hyväksyvät tarjoukset.',
    'allow_approve_expired_quote' => 'Salli vanhentuneen tarjouksen hyväksyminen',
    'allow_approve_expired_quote_help' => 'Salli asiakkaiden hyväksyä vanhentuneita tarjouksia.',
    'invoice_workflow' => 'Lasku Workflow',
    'quote_workflow' => 'Tarjouksen työnkulku',
    'client_must_be_active' => 'Virhe:  asiakas must be active',
    'purge_client' => 'Purge asiakas',
    'purged_client' => 'onnistuneesti purged asiakas',
    'purge_client_warning' => 'Kaikki liittyvät tallenteet (laskut, tehtävät, kulut, dokumentit, jne) tullaan myös poistamaan. ',
    'clone_product' => 'Kopioi tuote',
    'item_details' => 'Tuotteen tiedot',
    'send_item_details_help' => 'Lähetä tuoterivin tiedot maksujärjestelmään.',
    'view_proposal' => 'Näytä ehdotus',
    'view_in_portal' => 'Näytä Portaalissa',
    'cookie_message' => 'tämä verkkosivu uses cookies  ensure you get  best experience on our verkkosivu.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'kauppias luodaan',
    'vendors_will_create' => 'kauppiaat  luodaan',
    'created_vendors' => 'Onnistuneesti luotu :count kauppias(ta)',
    'import_vendors' => 'Tuo kauppiaat',
    'company' => 'yritys',
    'client_field' => 'asiakas kenttä',
    'contact_field' => 'kontakti kenttä',
    'product_field' => 'Tuote kenttä',
    'task_field' => 'Tehtävä kenttä',
    'project_field' => 'Projekti kenttä',
    'expense_field' => 'kulu kenttä',
    'vendor_field' => 'Kauppias kenttä',
    'company_field' => 'yritys kenttä',
    'invoice_field' => 'Lasku kenttä',
    'invoice_surcharge' => 'Lasku Surcharge',
    'custom_task_fields_help' => 'Lisää  kenttä kun tehtävä luodaan.',
    'custom_project_fields_help' => 'Lisää  kenttä luotaessa projekti.',
    'custom_expense_fields_help' => 'Lisää  kenttä luotaessa kulu.',
    'custom_vendor_fields_help' => 'Lisää  kenttä luotaessa kauppias.',
    'messages' => 'Viestit',
    'unpaid_invoice' => 'Maksamatonl lasku',
    'paid_invoice' => 'Paid Lasku',
    'unapproved_quote' => 'Hyväksymätön tarjous',
    'unapproved_proposal' => 'Hyväksymätön ehdotus',
    'autofills_city_state' => 'automaattinen-fills city/state',
    'no_match_found' => 'ei match found',
    'password_strength' => 'salasana Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Merkitse',
    'updated_task_status' => 'Onnistuneesti päivitetty tehtävän tila',
    'background_image' => 'Background Image',
    'background_image_help' => 'käytä the :link  manage sinun images, we recommend using  small tiedosto.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway palkkio Item',
    'gateway_fee_description' => 'Gateway palkkio Surcharge',
    'gateway_fee_discount_description' => 'Gateway palkkio Discount',
    'show_payments' => 'näytä maksut',
    'show_aging' => 'Näytä ikääntyminen',
    'reference' => 'Reference',
    'amount_paid' => 'määrä Paid',
    'send_notifications_for' => 'lähetä Notifications For',
    'all_invoices' => 'All laskut',
    'my_invoices' => 'My laskut',
    'payment_reference' => 'maksu Reference',
    'maximum' => 'maksimi',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => ' Anna sähköpostiosoitteesi',
    'please_enter_your_password' => ' Anna salasanasi',
    'please_enter_your_url' => 'Anna sinun URL-osoitteesi',
    'please_enter_a_product_key' => ' Anna tuoteavain',
    'an_error_occurred' => ' virhe occurred',
    'overview' => 'Yleiskatsaus',
    'copied_to_clipboard' => 'Copied :arvo    clipboard',
    'error' => 'Virhe',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Lisäksi',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Lisää nimike',
    'total_amount' => 'yhteensä määrä',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Lasku tila',
    'click_plus_to_add_item' => 'Napsauta +  lisätäksesi nimikkeen',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => ' valitse  päivämäärä',
    'please_select_a_client' => ' valitse  asiakas',
    'language' => 'Language',
    'updated_at' => 'päivitetty',
    'please_enter_an_invoice_number' => ' Ayötä  laskunumero',
    'please_enter_a_quote_number' => 'Ole hyvä ja anna tarjouksen numero',
    'clients_invoices' => ':asiakas\'s laskut',
    'viewed' => 'Nähty',
    'approved' => 'Approved',
    'invoice_status_1' => 'Luonnos',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Nähty',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Onnistuneesti merkitty lasku lähetetyksi',
    'please_enter_a_client_or_contact_name' => ' Anna  asiakkaan tai yhteyshenkilön nimi',
    'restart_app_to_apply_change' => 'Uudelleenkäynnistä sovellus ottaaksesi muutoksen käyttöön',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank kontakti',
    'no_records_found' => 'ei records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Näytä tehtävät',
    'email_reminders' => 'Email muistutukset',
    'reminder1' => 'ensimmäinen muistutus',
    'reminder2' => 'toinen muistutus',
    'reminder3' => 'Third muistutus',
    'send' => 'lähetä',
    'auto_billing' => 'Automaattinen laskutus',
    'button' => 'Button',
    'more' => 'Lisää',
    'edit_recurring_invoice' => 'muokkaa toistuva Lasku',
    'edit_recurring_quote' => 'Muokkaa toistuvaa tarjousta',
    'quote_status' => 'Tarjouksen tila',
    'please_select_an_invoice' => ' valitse  lasku',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'maksu tila',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'lähetä receipt    asiakas',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Tarjous on onnistuneesti merkitty lähetetyksi',
    'custom_module_settings' => 'muokattu Module asetukset',
    'ticket' => 'tiketti',
    'tickets' => 'Tickets',
    'ticket_number' => 'tiketti #',
    'new_ticket' => 'uusi tiketti',
    'edit_ticket' => 'muokkaa tiketti',
    'view_ticket' => 'Näytä Tiketti',
    'archive_ticket' => 'Arkistoi tiketti',
    'restore_ticket' => 'palauta tiketti',
    'delete_ticket' => 'Poista tiketti',
    'archived_ticket' => 'onnistuneesti arkistoitu tiketti',
    'archived_tickets' => 'onnistuneesti arkistoitu tiketit',
    'restored_ticket' => 'onnistuneesti palautettu tiketti',
    'deleted_ticket' => 'onnistuneesti poistettu tiketti',
    'open' => 'avaa',
    'new' => 'uusi',
    'closed' => 'suljettu',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'viime päivitetty',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'ei erä päivämäärä set',
    'assigned_to' => 'Assigned  ',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting vastaus',
    'ticket_close' => 'sulje tiketti',
    'ticket_reopen' => 'Reopen tiketti',
    'ticket_open' => 'avaa tiketti',
    'ticket_split' => 'Split tiketti',
    'ticket_merge' => 'Merge tiketti',
    'ticket_update' => 'päivitä tiketti',
    'ticket_settings' => 'tiketti asetukset',
    'updated_ticket' => 'tiketti päivitetty',
    'mark_spam' => 'Merkitse roskapostiksi',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'nimi taken',
    'local_part_available' => 'nimi saatavilla',
    'local_part_invalid' => 'epäkelpo name (alpha numeric only, no spaces',
    'local_part_help' => 'Mukauta  paikallinen part  sinun inbound support sähköposti, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is  recognizable sender which is displayed instead of  sähköposti osoite, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'asiakas uploads',
    'enable_client_upload_help' => 'Allow asiakkaat  upload dokumentit/attachments',
    'max_file_size_help' => 'maksimi tiedosto koko (KB) is limited by sinun post_max_size ja upload_max_filesize variables  set in sinun PHP.INI',
    'max_file_size' => 'maksimi tiedosto koko',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Pilkulla erotettu lista  allowed mime types, jätä tyhjäksi  kaikki',
    'ticket_number_start_help' => 'tiketti numero must be greater than  current tiketti numero',
    'new_ticket_template_id' => 'uusi tiketti',
    'new_ticket_autoresponder_help' => 'Selecting  template will send  auto response    asiakas/kontakti when  uusi tiketti is luotu',
    'update_ticket_template_id' => 'päivitetty tiketti',
    'update_ticket_autoresponder_help' => 'Selecting  template will send  auto response    asiakas/kontakti when  tiketti is päivitetty',
    'close_ticket_template_id' => 'suljettu tiketti',
    'close_ticket_autoresponder_help' => 'Selecting  template will send  auto response    asiakas/kontakti when  tiketti is closed',
    'default_priority' => 'oletus priority',
    'alert_new_comment_id' => 'uusi comment',
    'alert_comment_ticket_help' => 'Selecting  template will send  notification ( agent) when  comment is made.',
    'alert_comment_ticket_email_help' => 'pilkulla erotetut sähköpostit  bcc on uusi comment.',
    'new_ticket_notification_list' => 'Täydentävät Uusi tiketti -ilmoitukset',
    'update_ticket_notification_list' => 'Täydentävät Uusi kommentti -ilmoitukset',
    'comma_separated_values' => 'admin@esimerkki.com, supervisor@esimerkki.com',
    'alert_ticket_assign_agent_id' => 'tiketti assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting  template will send  notification ( agent) when  tiketti is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Täydentävät Uusi tiketin kohdennus -ilmoitukset',
    'alert_ticket_assign_agent_id_help' => 'pilkulla erotetut sähköpostit  bcc on tiketti assignment.',
    'alert_ticket_transfer_email_help' => 'pilkulla erotetut sähköpostit  bcc on tiketti transfer.',
    'alert_ticket_overdue_agent_id' => 'tiketti overdue',
    'alert_ticket_overdue_email' => 'Täydentävät Uusi tiketti yliajalla -ilmoitukset',
    'alert_ticket_overdue_email_help' => 'pilkulla erotetut sähköpostit  bcc on tiketti overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting  template will send  notification ( agent) when  tiketti becomes overdue.',
    'ticket_master' => 'tiketti Master',
    'ticket_master_help' => 'Has  ability  assign ja transfer tiketit. Assigned as  oletus agent  kaikki tiketit.',
    'default_agent' => 'oletus Agent',
    'default_agent_help' => 'If selected will automatically be assigned  kaikki inbound tiketit',
    'show_agent_details' => 'Näytä agentin tiedot vastauksissa',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'tiketti ei löydy',
    'add_template' => 'Lisää mallipohja',
    'ticket_template' => 'tiketti pohja',
    'ticket_templates' => 'tiketti pohjat',
    'updated_ticket_template' => 'päivitetty tiketti pohja',
    'created_ticket_template' => 'luotu tiketti pohja',
    'archive_ticket_template' => 'Arkistoi pohja',
    'restore_ticket_template' => 'palauta pohja',
    'archived_ticket_template' => 'onnistuneesti arkistoitu template',
    'restored_ticket_template' => 'onnistuneesti palautettu template',
    'close_reason' => 'Let us know why you on closing this tiketti',
    'reopen_reason' => 'Let us know why you on reopening this tiketti',
    'enter_ticket_message' => ' Kirjoita viesti päivittääksesi tiketin',
    'show_hide_all' => 'Näytä / Piilota kaikki',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using  mobile app you may need  do  full refresh.',
    'enable_proposals_for_background' => 'To upload  background kuva :link  enable  proposals module.',
    'ticket_assignment' => 'tiketti :ticket_number on assigned   :agent',
    'ticket_contact_reply' => 'tiketti :ticket_number on päivitetty by asiakas :kontakti',
    'ticket_new_template_subject' => 'tiketti :ticket_number on luotu.',
    'ticket_updated_template_subject' => 'tiketti :ticket_number on päivitetty.',
    'ticket_closed_template_subject' => 'tiketti :ticket_number on closed.',
    'ticket_overdue_template_subject' => 'tiketti :ticket_number is nyt overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent tiketti',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter tiketti numero  merge into',
    'merge_from_to' => 'tiketti #:old_ticket merged into tiketti #:new_ticket',
    'merge_closed_ticket_text' => 'tiketti #:old_ticket was closed ja merged into tiketti#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'tiketti #:old_ticket was closed ja merged into this tiketti',
    'merge_placeholder' => 'Merge tiketti #:tiketti into  following tiketti',
    'select_ticket' => 'Select tiketti',
    'new_internal_ticket' => 'uusi internal tiketti',
    'internal_ticket' => 'Internal tiketti',
    'create_ticket' => 'luo tiketti',
    'allow_inbound_email_tickets_external' => 'uusi Tickets by sähköposti (asiakas)',
    'allow_inbound_email_tickets_external_help' => 'Allow asiakkaat  create uusi tiketit by sähköposti',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'kiitos  sinun patience while we work  implement these ominaisuudet.\n\nWe hope  have them valmis in  next few kuukautta.\n\nUntil then we\'ll continue  support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'tänään',
    'current' => 'nykyinen',
    'previous' => 'Previous',
    'current_period' => 'nykyinen kausi',
    'comparison_period' => 'Comparison kausi',
    'previous_period' => 'Previous kausi',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare  ',
    'last_week' => 'viime viikko',
    'clone_to_invoice' => 'kloonaa  Lasku',
    'clone_to_quote' => 'Kopioi  tarjous',
    'convert' => 'Convert',
    'last7_days' => 'viime 7 päivää',
    'last30_days' => 'viime 30 päivää',
    'custom_js' => 'muokattu JS',
    'adjust_fee_percent_help' => 'Adjust percent  tili  palkkio',
    'show_product_notes' => 'Näytä tuotteen tiedot',
    'show_product_notes_help' => 'Sisällytä <b>kuvaus ja kustannukset</b> tuotteen pudotusvalikkoon',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'kiitos you  using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => ' rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => ' authenticate  change this asetus',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => ' authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Automaattinen tehtävien aloitus',
    'budgeted' => 'Budjetoitu',
    'please_enter_a_name' => ' Ole hyvä ja anna nimi',
    'click_plus_to_add_time' => 'Napsauta + lisätäksesi ajan',
    'design' => 'malli',
    'password_is_too_short' => 'salasana on liian lyhyt',
    'failed_to_find_record' => 'Failed  find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Asettaa automaattisesti <b>Voimassa saakka </b> arvon tarjouksiin näin monen päivän päähän tulevaisuuteen. Jätä tyhjäksi jos et halua käyttää tätä.',
    'usually_pays_in_days' => 'päivää',
    'requires_an_enterprise_plan' => 'Requires  enterprise plan',
    'take_picture' => 'Ota kuva',
    'upload_file' => 'Lataa tiedosto palvelimelle',
    'new_document' => 'Uusi asiakirja',
    'edit_document' => 'Muokkaa asiakirjaa',
    'uploaded_document' => 'onnistuneesti lähetetty dokumentti',
    'updated_document' => 'onnistuneesti päivitetty dokumentti',
    'archived_document' => 'onnistuneesti arkistoitu dokumentti',
    'deleted_document' => 'onnistuneesti poistettu dokumentti',
    'restored_document' => 'onnistuneesti palautettu dokumentti',
    'no_history' => 'ei History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'ei record selected',
    'error_unsaved_changes' => ' save tai peruuta sinun muutokset',
    'thank_you_for_your_purchase' => 'kiitos you  sinun purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual tilaus',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count käyttäjää',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Anna  etunimi',
    'please_enter_a_last_name' => 'Anna  sukunimi',
    'please_agree_to_terms_and_privacy' => 'Ole hyvä ja hyväksy palveluehtomme sekä tietosuojakäytäntömme luodaksesi käyttäjätilin.',
    'i_agree_to_the' => 'Hyväksyn',
    'terms_of_service_link' => 'palvelun ehdot',
    'privacy_policy_link' => 'Tietosuojakäytäntö',
    'view_website' => 'Näytä verkkosivu',
    'create_account' => 'Luo käyttäjätili',
    'email_login' => 'Email Login',
    'late_fees' => 'Viivästysmaksut',
    'payment_number' => 'maksu numero',
    'before_due_date' => 'Ennen  eräpäivää',
    'after_due_date' => 'Eräpäivän jälkeen',
    'after_invoice_date' => 'Laskun päiväyksen jälkeen',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Onnistuneesti luotu käyttäjä',
    'primary_font' => 'Ensisijainen kirjasin',
    'secondary_font' => 'toissijainen kirjasin',
    'number_padding' => 'numero Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge kenttä',
    'company_value' => 'yritys Value',
    'credit_field' => 'luotto kenttä',
    'payment_field' => 'maksu kenttä',
    'group_field' => 'ryhmä kenttä',
    'number_counter' => 'numero Counter',
    'number_pattern' => 'numero Pattern',
    'custom_javascript' => 'Muokautettu JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Liitä PDF',
    'attach_documents' => 'Liitä asiakirjoja',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'palkkio määrä',
    'fee_percent' => 'Palkkio prosentti',
    'fee_cap' => 'palkkio Cap',
    'limits_and_fees' => 'Limits/palkkiot',
    'credentials' => 'Tunnukset',
    'require_billing_address_help' => 'Vaadi asiakkaita antamaan laskutusosoittensa.',
    'require_shipping_address_help' => 'Require asiakas  provide their shipping osoite',
    'deleted_tax_rate' => 'Verokanta onnistuneesti poistettu ',
    'restored_tax_rate' => 'Verokanta onnistuneesti palautettu',
    'provider' => 'Tarjoaja',
    'company_gateway' => 'maksu Gateway',
    'company_gateways' => 'maksu Gateways',
    'new_company_gateway' => 'uusi Gateway',
    'edit_company_gateway' => 'muokkaa Gateway',
    'created_company_gateway' => 'onnistuneesti luotu gateway',
    'updated_company_gateway' => 'onnistuneesti päivitetty gateway',
    'archived_company_gateway' => 'onnistuneesti arkistoitu gateway',
    'deleted_company_gateway' => 'onnistuneesti poistettu gateway',
    'restored_company_gateway' => 'onnistuneesti palautettu gateway',
    'continue_editing' => 'Jatka muokkausta',
    'default_value' => 'Oletus arvo',
    'currency_format' => 'Valuutan muoto',
    'first_day_of_the_week' => 'Viikon ensimmäinen päivä',
    'first_month_of_the_year' => 'Vuoden ensimmäinen kuukausi',
    'symbol' => 'Symboli',
    'ocde' => 'Koodi',
    'date_format' => 'Date Format',
    'datetime_format' => 'Päivä-Aika esitysmuoto',
    'send_reminders' => 'lähetä muistutukset',
    'timezone' => 'Aikavyöhyke',
    'filtered_by_group' => 'Filtered by ryhmä',
    'filtered_by_invoice' => 'Filtered by Lasku',
    'filtered_by_client' => 'Filtered by asiakas',
    'filtered_by_vendor' => 'Suodatettu: Kauppias',
    'group_settings' => 'ryhmä asetukset',
    'groups' => 'ryhmät',
    'new_group' => 'uusi ryhmä',
    'edit_group' => 'muokkaa ryhmä',
    'created_group' => 'onnistuneesti luotu ryhmä',
    'updated_group' => 'onnistuneesti päivitetty ryhmä',
    'archived_group' => 'onnistuneesti arkistoitu ryhmä',
    'deleted_group' => 'onnistuneesti poistettu ryhmä',
    'restored_group' => 'onnistuneesti palautettu ryhmä',
    'upload_logo' => 'Lataa Logo',
    'uploaded_logo' => 'Logo onnistuneesti ladattu palvelimelle',
    'saved_settings' => 'onnistuneesti saved asetus',
    'device_settings' => 'Device asetukset',
    'credit_cards_and_banks' => 'luotto Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate    next versio  Lasku Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'tervetuloa    uusi versio  Lasku Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'paina nappi alla  download  data.',
    'migration_import' => 'Awesome! Now you on ready  tuonti sinun migration. Go  sinun uusi installation  tuonti sinun data',
    'continue' => 'jatka',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Näytä tuotteen tiedot',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Oma Hyväksymätön tarjous -viesti',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Kauppiaan numerolaskuri',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Tarjouksen numeroinnin kuvio',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Jaettu lasku tarjous laskuri',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Tarjoussähköpostin otsikko',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Kauppiaan kaupunki',
    'vendor_state' => 'Kauppiaan alue',
    'vendor_country' => 'Kauppiaan maa',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Asiakkaan tiedot',
    'company_address' => 'Company Address',
    'quote_details' => 'Tarjouksen tiedot',
    'credit_details' => 'Hyvityksen tiedot',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Tarjous lähetetty',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Tarjous luettu',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Tarjous hyväksytty',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Tarjous on onnistuneesti muunnettu',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Tarjouksen summa',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Hae tarjouksia',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Hae kauppiaita',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Valitut tarjoukset',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Päivitä tarjous',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Päivitä kauppias',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Hyväksy tarjous',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Hae 1 tarjous',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Hae 1 kauppias',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Päättymätön',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Lisää aikatieto laskun tuoteriville',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Osittainen maksu',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Veron nimi 1',
    'tax_name2' => 'Veron nimi 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
